//@AKashta

import java.io.*;
import java.util.ArrayList;

public class Main {

    public static final boolean ADVANCED_MODE = true;
    public static final int MAX_POINTS = 50;
    public static final double PRECISION = 30;
    public static final int THRESHOLD = 300;

    public static final String START_TOKEN = "111001100011101101";
    public static final long DATA_LENGTH = 10000000;
    public static final long SPEED = 299792458;
    public static final long EARTH_R = 6378000;
    public static final long MIN_SAT_POS = 10000000;
    public static final long MAX_SAT_POS = 20000000;
    public static final int MIN_OFFSET = (int)((MIN_SAT_POS - EARTH_R) * DATA_LENGTH / SPEED);
    public static final int MAX_OFFSET = (int)((MAX_SAT_POS + EARTH_R) * DATA_LENGTH / SPEED);

    public static void main(String args[ ]) {
        //long startTime = System.currentTimeMillis();
        try {
            DataInputStream in = new DataInputStream(System.in);
            DataReader reader = new DataReader(in);
            Point result = null;

            int q = reader.readInt();
            ArrayList<Circle> sats = new ArrayList<Circle>(q);
            for(int i = 0; i < Math.min(q, MAX_POINTS); i++) {
                double x = reader.readDouble();
                double y = reader.readDouble();
                int offset = reader.readOffset();

                double radius = ((double)SPEED / DATA_LENGTH * offset);

                sats.add(new Circle(new Point(x, y),  radius));
            }

            if(sats.size() == 2) {
                ArrayList<Point> points = sats.get(0).intersect(sats.get(1));
                for(Point p : points) {
                    result = p;
                    break;
                }
            }  else {
                if(ADVANCED_MODE) {
                    result = advancedCalc(sats);
                } else {
                    result = simpleCalc(sats);
                }
            }

            System.out.println(result.x + " " + result.y);
            //long time = (System.currentTimeMillis() - startTime);
            //System.out.println("Time: " + time);
        } catch (Exception e) {
            System.out.println(e.getMessage());
        }
    }

    public static Point findRefPoint(ArrayList<Circle> sats){
        ArrayList<Point> points = new ArrayList<Point>();
        for(int i = 0; i < 2; i++) {
            for(int j = i + 1; j < 3; j++) {
                points.addAll(sats.get(i).intersect(sats.get(j)));
            }
        }

        Point p0 = null, p1 = null, p2 = null;
        for(Point p : points) {
            for(Point t : points) {
                if(p1 == null && t != p && p.distance(t) < THRESHOLD){
                    p1 = t;
                    continue;
                }
                if(p1 != null && t != p && t != p1 && p.distance(t) < THRESHOLD){
                    p2 = t;
                    break;
                }
            }
            if(p1 != null && p2 != null) {
                p0 = p;
                break;
            } else {
                p1 = null;
                p2 = null;
            }
        }
        return new Point((p0.x + p1.x + p2.x) / 3, (p0.y + p1.y + p2.y) / 3);
    }

    public static Point advancedCalc(ArrayList<Circle> sats){
        ArrayList<Point> allPoints = new ArrayList<Point>();
        for(int i = 0; i < sats.size() - 1; i++) {
            for(int j = i + 1; j < sats.size(); j++) {
                allPoints.addAll(sats.get(i).intersect(sats.get(j)));
            }
        }

        int count = 0;
        double sumX = 0;
        double sumY = 0;

        for(Point p : allPoints) {
            boolean containsInAll = true;
            for (Circle sat : sats){
                if(!sat.hasPoint(p)) {
                    containsInAll = false;
                    break;
                }
            }
            if(containsInAll) {
                count++;
                sumX += p.x;
                sumY += p.y;
            }
        }
        return new Point(sumX / count, sumY / count);
    }

    public static Point simpleCalc(ArrayList<Circle> sats){
        int count = 0;
        double sumX = 0;
        double sumY = 0;

        Point refPoint = findRefPoint(sats);
        for(int i = 0; i < sats.size() - 1; i++) {
            for(int j = i + 1; j < sats.size(); j++) {
                for(Point p : sats.get(i).intersect(sats.get(j))) {
                    if(refPoint.distance(p) < THRESHOLD) {
                        count++;
                        sumX += p.x;
                        sumY += p.y;
                    }
                }
            }
        }
        return new Point(sumX / count, sumY / count);
    }

    public static class DataReader {
        private DataInputStream _in;

        public DataReader(DataInputStream in){
            _in = in;
        }

        public int readOffset() throws Exception {
            byte firstByte = _in.readByte();
            int offset = 1;
            while( _in.readByte() == firstByte) {
                offset++;
            }
            int needToSkip = ((MIN_OFFSET - offset) / 10) * 10;
            _in.skipBytes(needToSkip);
            offset += needToSkip;

            byte[] buffer = new byte[MAX_OFFSET - offset];
            _in.read(buffer);
            _in.skipBytes((int) DATA_LENGTH - offset - buffer.length - 1 + 2);

            StringBuilder sb = new StringBuilder(buffer.length / 10);
            for(int i = 0; i < buffer.length / 10; i++ ){
                sb.append((char) buffer[i * 10]);
            }

            int index = sb.indexOf(START_TOKEN)* 10;

            return index + offset;
        }

        public String readLine() throws Exception {
            StringBuilder sb = new StringBuilder();
            char c;
            while((c = (char)_in.readByte()) != '\r') {
                sb.append(c);
            }
            _in.readByte(); // read '\n' char
            return  sb.toString();
        }

        public int readInt() throws Exception {
            String s = readLine();
            return Integer.parseInt(s);
        }

        public Double readDouble() throws Exception {
            String s = readLine();
            return Double.parseDouble(s);
        }
    }

    public static class Point {
        public double x;
        public double y;

        public Point(double x, double y) {
            this.x = x;
            this.y = y;
        }

        public double distance() {
            return Math.sqrt(x*x + y*y);
        }

        public double distance(Point p) {
            return Math.sqrt(Math.pow(x - p.x, 2) + Math.pow(y - p.y, 2));
        }
    }

    public static class Circle {
        public Point center;
        public double radius;
        public Circle(Point p, double r) {
            center = p;
            radius = r;
        }

        public ArrayList<Point> intersect(Circle c) {
            ArrayList<Point> result = new ArrayList<Point>();

            double dx = c.center.x - center.x;
            double dy = c.center.y - center.y;
            double d = Math.sqrt((dy * dy) + (dx * dx));

            if(d < Math.abs(radius - c.radius)) {
                if(radius < c.radius)
                    radius += Math.abs(radius - c.radius) - d + 0.1;
                else
                    c.radius += Math.abs(radius - c.radius) - d + 0.1;
            }
            if (d > (radius + c.radius)) {
                double add = (d - (radius + c.radius))/ 2.0 + 0.1;
                radius += add;
                c.radius += add;
            }

            if (d > (radius + c.radius) || d < Math.abs(radius - c.radius)) {
                //System.out.println("do not intersect");
                return result;
            }

            double a = ((radius * radius) - (c.radius * c.radius) + ( d *d)) / (2.0 * d);

            Point p2 = new Point(center.x + (dx * a/d), center.y + (dy * a/d));

            double h = Math.sqrt((radius * radius) - (a*a));
            double rx = -dy * (h/d);
            double ry = dx * (h/d);

            Point p = new Point(p2.x + rx, p2.y + ry);
            if(p.distance() <= EARTH_R) {
                result.add(p);
            }
            p = new Point(p2.x - rx, p2.y - ry);
            if(p.distance() <= EARTH_R) {
                result.add(p);
            }

            return result;
        }

        public boolean hasPoint(Point p) {
            double d = center.distance(p);
            return Math.abs(d - radius) <= PRECISION;
        }
    }
}