//@Leng
import java.io.*;

public class HabrContest {
  static class Coords {
    double X = 0.0;
    double Y = 0.0;
    double R = 0.0;
  }
  static class HCReader {
    byte[] sbuf = new byte[10000000];
    byte[] buf = new byte[64];
    int last = 0;
    InputStream in;
    HCReader( InputStream is ){ in = is; }
    int getInt() throws IOException {
      skipNT();
      fillBuf();
      return Integer.parseInt(new String(buf, 0, last));
    }
    double getDouble() throws IOException {
      skipNT();
      fillBuf();
      return Double.parseDouble(new String(buf, 0, last));
    }
    byte[] getSeq() throws IOException {
      skipNT();
      if( last < 0 ) throw new IOException();
      sbuf[0] = (byte)last;
      last = 1;
      while( last < sbuf.length ){
        int r = in.read( sbuf, last, sbuf.length-last );
        if( r < 0 ) break;
        last += r;
      }
      while( last < sbuf.length ) sbuf[last++] = 0;

      int b = in.read();
      while( b > 0 && !isNT(b) ) b = in.read();

      return sbuf;
    }
    void skipNT() throws IOException {
      int b = in.read();
      while( isNT(b) ) b = in.read();
      last = b;
    }
    void fillBuf() throws IOException {
      if( last < 0 ) return;
      int b = last;
      last = 0;
      do{
        buf[last] = (byte) b;
        last++;
        b = in.read();
      }while( b > 0 && !isNT(b) && last < buf.length );
    }
    boolean isNT( int b ){
      return (b<33) || (b>125);
    }
  }

  public static void main( String[] args ){
    int i, N=0;
    Coords S[]=null;
    try{
      HCReader reader = new HCReader(System.in);

      int n = reader.getInt();
      S = new Coords[n];

      for( i = 0; i < n; i++ ){
        S[i] = new Coords();
        S[i].X = reader.getDouble();
        S[i].Y = reader.getDouble();
        int phase = getPhase( reader.getSeq() );
        if( phase == 0 ){
          n--; i--;
          continue;
        }
        S[i].R = phase * 29.9792458;
        N++;
      }
    }catch(Exception e){}

    if(N<2) System.exit(-1);

    Coords res = new Coords();
    double err = getErr(S, N, res);

    long startTime = System.currentTimeMillis();

    while( err > 0.001 ){
      double dX = 0.0, dY = 0.0;
      for( i = 0; i < N; i++ ){
        double R = Math.sqrt((res.X-S[i].X)*(res.X-S[i].X)+(res.Y-S[i].Y)*(res.Y-S[i].Y));
        double dR = R - S[i].R;
        if( Math.abs(dR) < 15. ) continue;
        dX += dR*(S[i].X-res.X)/R;
        dY += dR*(S[i].Y-res.Y)/R;
      }
      res.X += dX/N;
      res.Y += dY/N;

      err = getErr(S, N, res);
      if( System.currentTimeMillis() - startTime > 200 ) break;
    }

    System.out.print(res.X);
    System.out.print(" ");
    System.out.print(res.Y);
    System.out.println();
  }

  static int getPhase( byte[] seq ){
    if( seq==null || seq.length<880210 ) return 0;

    int i = 0;
    while( seq[i]==seq[0] ) i++;

    int label = 0;
    for( i = 120810 + (i%10); i<880210; i+=10 ){
      label <<= 1;
      if( seq[i] == 0x31 ) label |= 0x01;
      if( label == 0xE63B7783 ){
        i -= 310;
        break;
      }
    }
    if( i > 880209 ) return 0;
    return i;
  }

  static double getErr( Coords[] s, int N, Coords c ){
    double err = 0.0;
    for( int i = 0; i < N; i++ ){
      double dR = Math.sqrt((c.X-s[i].X)*(c.X-s[i].X)+(c.Y-s[i].Y)*(c.Y-s[i].Y))-s[i].R;
      if( Math.abs(dR) < 15. ) continue;
      err += Math.abs(dR) - 15.;
    }
    return err;
  }
}
