//@MaxAvilov
import java.io.IOException;
import java.util.ArrayList;

public class Glonass {
	static final int TEST_RANDOM_SEQ_LEN = 64;
	static final byte[] TEST_RANDOM_SEQ = { 49, 49, 49, 48, 48, 49, 49, 48, 48,
			48, 49, 49, 49, 48, 49, 49, 48, 49, 49, 49, 48, 49, 49, 49, 49, 48,
			48, 48, 48, 48, 49, 49, 48, 48, 49, 49, 48, 48, 49, 49, 49, 48, 48,
			49, 48, 49, 48, 49, 48, 49, 48, 48, 49, 49, 48, 48, 48, 48, 49, 49,
			49, 49, 49, 48, };
	static final int SKIP_SIGNALS = 12000;
	static final int BUFFER_LEN = 1000000 - SKIP_SIGNALS;
	static final int SKIP_BYTES = 9000000;
	static final int X = 0;
	static final int Y = 1;

	static String readLineFromStdIn(final int maxLen) throws IOException {
		byte[] result = new byte[maxLen];
		int strLen = 0;
		int buffer;
		while ((buffer = System.in.read()) != 0x0A) {
			if (buffer != 0x0D) {
				if (strLen >= maxLen)
					throw new IndexOutOfBoundsException(
							"Что-то не так со строкой в StdIn (слишком длинная).");
				result[strLen++] = (byte) buffer;
			}
		}
		return new String(result, 0, strLen, "ISO-8859-1");
	}

	static double dist(double[] p1, double[] p2) {
		return Math.sqrt((p1[X] - p2[X]) * (p1[X] - p2[X]) + (p1[Y] - p2[Y])
				* (p1[Y] - p2[Y]));
	}

	public static void main(String[] args) throws IOException {
		int numSats = Integer.valueOf(readLineFromStdIn(11));
		if (numSats > 16)
			numSats = 16;
		double[][] satPos = new double[numSats][2];
		double[] seqOffsets = new double[numSats];
		byte[] buffer = new byte[BUFFER_LEN];
		for (int i = 0; i < numSats; i++) {
			satPos[i][X] = Double.valueOf(readLineFromStdIn(24));
			satPos[i][Y] = Double.valueOf(readLineFromStdIn(24));
			long needSkip = SKIP_SIGNALS;
			while ((needSkip -= System.in.skip(needSkip)) > 0)
				;
			int bytesRead = 0;
			while ((bytesRead += System.in.read(buffer, bytesRead, BUFFER_LEN
					- bytesRead)) < BUFFER_LEN)
				;
			int offset = 0;
			while (buffer[0] == buffer[offset])
				offset++;
			offset %= 10;
			int posInData = 0;
			int posInRandom = 0;
			while (posInRandom < TEST_RANDOM_SEQ_LEN) {
				if (offset + posInData * 10 >= BUFFER_LEN)
					throw new IndexOutOfBoundsException(
							"Спутник существенно дальше, чем в 26378 км. от объекта? Так нечестно!");
				if (buffer[offset + posInData * 10] == TEST_RANDOM_SEQ[posInRandom]) {
					posInRandom++;
				} else {
					posInRandom = 0;
				}
				posInData++;
			}
			seqOffsets[i] = ((SKIP_SIGNALS + offset + (posInData - TEST_RANDOM_SEQ_LEN) * 10) * 299792458.0) / 10000000.0;
			needSkip = SKIP_BYTES;
			while ((needSkip -= System.in.skip(needSkip)) > 0)
				;
			readLineFromStdIn(0);
		}
		ArrayList<double[]> points = new ArrayList<double[]>();
		for (int i = 0; i < numSats; i++) {
			for (int j = i + 1; j < numSats; j++) {
				double diffX = satPos[j][X] - satPos[i][X];
				double diffY = satPos[j][Y] - satPos[i][Y];
				double satDist = Math.sqrt(diffX * diffX + diffY * diffY);
				if (satDist <= seqOffsets[i] + seqOffsets[j]) {
					double joinLDist1 = (satDist * satDist + seqOffsets[i]
							* seqOffsets[i] - seqOffsets[j] * seqOffsets[j])
							/ (2 * satDist);
					double h = Math.sqrt(seqOffsets[i] * seqOffsets[i]
							- joinLDist1 * joinLDist1);
					double x1 = satPos[i][X] + diffX * joinLDist1 / satDist
							+ (diffY / satDist) * h;
					double y1 = satPos[i][Y] + diffY * joinLDist1 / satDist
							- (diffX / satDist) * h;
					double x2 = satPos[i][X] + diffX * joinLDist1 / satDist
							- (diffY / satDist) * h;
					double y2 = satPos[i][Y] + diffY * joinLDist1 / satDist
							+ (diffX / satDist) * h;
					if (Math.sqrt(x1 * x1 + y1 * y1) <= 6378000) {
						points.add(new double[] { x1, y1 });
					}
					if (Math.sqrt(x2 * x2 + y2 * y2) <= 6378000) {
						points.add(new double[] { x2, y2 });
					}
				}
			}
		}
		if (points.size() > 2) {
			int totalPoints = points.size();
			double[] baseChoice = new double[totalPoints];
			for (int i = 0; i < totalPoints; i++) {
				for (int j = 0; j < totalPoints; j++) {
					if (i != j) {
						baseChoice[i] += dist(points.get(i), points.get(j));
					}
				}
			}
			double minDistSum = baseChoice[0];
			int basePointIdx = 0;
			for (int i = 1; i < totalPoints; i++) {
				if (baseChoice[i] < minDistSum) {
					minDistSum = baseChoice[i];
					basePointIdx = i;
				}
			}
			double avgX = points.get(basePointIdx)[X];
			double avgY = points.get(basePointIdx)[Y];
			double sigma = minDistSum / totalPoints;
			int validPoints = 1;
			for (int i = 0; i < totalPoints; i++) {
				if (i != basePointIdx) {
					if (dist(points.get(i), points.get(basePointIdx)) < sigma) {
						validPoints++;
						avgX += points.get(i)[X];
						avgY += points.get(i)[Y];
					}
				}
			}
			avgX /= validPoints;
			avgY /= validPoints;
			System.out.format("%.9e %.9e\n", avgX, avgY);
		} else if (points.size() != 0) {
			if (points.size() == 2 && dist(points.get(0), points.get(1)) < 1000) {
				System.out.format("%.9e %.9e\n",
						(points.get(0)[X] + points.get(1)[X]) / 2,
						(points.get(0)[Y] + points.get(1)[Y]) / 2);
			} else {
				System.out.format("%.9e %.9e\n", points.get(0)[X],
						points.get(0)[Y]);
			}
		} else {
			System.out
					.println("Поиск спутников ГЛОНАСС'63. Ждите, пока РОСКОСМОС распилит бюджет.");
		}
	}
}
