//@Nobodyhave
import java.io.*;
import java.nio.ByteBuffer;
import java.nio.channels.Channels;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ForkJoinPool;
import java.util.concurrent.RecursiveAction;

public class GpsCalculator {
    public final static String PI = "3.1415926535897932384626433832795028841971693993751058209749445923078164062862089986280348253421170679821480865132823066470938446";
    public static final double UNIT_DISTANCE = 29.9792458;
    public static final int SATELLITE_SEQ_LENGTH = 1000000;
    public static final int THRESHOLD = (SATELLITE_SEQ_LENGTH + 8)/ 8;
    public static byte[] seq;
    public static byte[] LONGEST_CHAIN;
    public static int LONGEST_CHAIN_OFFSET = 637548;
    public static Satellite[] mSatellites;

    static {
        LONGEST_CHAIN = new byte[19];
        for (int i = 0; i < 10; i++) {
            LONGEST_CHAIN[i] = 49;
        }
    }

    public static void main(String[] args) throws NoSuchAlgorithmException, IOException {
        //prepareSequence();
        getSatellites();
        Point<Double, Double> avgPoint = calcAvgPoint();
        System.out.print(avgPoint.getKey() + " " + avgPoint.getValue());
    }

    private static void prepareSequence() {
        seq = new byte[SATELLITE_SEQ_LENGTH];
        new ForkJoinPool().invoke(new SeqGen(0, SATELLITE_SEQ_LENGTH));
        findLongestChain();
    }

    private static void findLongestChain() {
        int offset = 0;
        int count = 1;
        int max = 0;
        byte seqChar = 48;
        for (int i = 1; i < SATELLITE_SEQ_LENGTH; i++) {
            if (seq[i] == seq[i - 1]) {
                count++;
            } else {
                if (count > max) {
                    seqChar = seq[i - 1];
                    max = count;
                    offset = i - count;
                }
                count = 1;
            }
        }

        LONGEST_CHAIN_OFFSET = offset;
        LONGEST_CHAIN = new byte[max];
        for (int i = 0; i < max; i++) {
            LONGEST_CHAIN[i] = seqChar;
        }
    }

    private static void getSatellites() throws IOException {
        ByteBuffer bb = ByteBuffer.allocate(51000000);
        Channels.newChannel(System.in).read(bb);
        bb.rewind();

        int satCount = Integer.parseInt(readStrFromBuf(bb));
        mSatellites = new Satellite[satCount];
        final byte[] bytes = new byte[10000000];
        for (int i = 0; i < Math.min(satCount, 5); i++) {
            double x = Double.parseDouble(readStrFromBuf(bb));
            double y = Double.parseDouble(readStrFromBuf(bb));
            readByteArrFromBuf(bb, bytes);
            mSatellites[i] = new Satellite(x, y, bytes);
        }
    }

    private static String readStrFromBuf(ByteBuffer bb) {
        StringBuilder sb = new StringBuilder();
        char c;
        while ((c = (char)bb.get()) != 13) {
            sb.append(c);
        }
        bb.get();

        return sb.toString();
    }

    private static void readByteArrFromBuf(ByteBuffer bb, byte[] arr) {
        bb.get(arr);
        bb.get();
        bb.get();
    }

    private static Point<Double, Double> calcAvgPoint() {
        int c1 = 0, c2, c3;
        List<Point<Double, Double>> pList = new ArrayList<Point<Double, Double>>();
        if(mSatellites.length == 2) {
            Point<Double, Double> p12 = Triangle.calculateTwoSatelliteIntersection(mSatellites[0], mSatellites[1]);
            Point<Double, Double> p21 = Triangle.calculateTwoSatelliteIntersection(mSatellites[1], mSatellites[0]);
            double distP1 = Math.sqrt(Math.pow(p12.getKey(),2) + Math.pow(p12.getValue(),2));
            double distP2 = Math.sqrt(Math.pow(p21.getKey(),2) + Math.pow(p21.getValue(),2));
            if(distP1 <= 6378000) {
                pList.add(p12);
            }
            if(distP2 <= 6378000) {
                pList.add(p21);
            }

        } else {
            while (c1 < mSatellites.length - 2) {
                c2 = c1 + 1;
                while (c2 < mSatellites.length - 1) {
                    c3 = c2 + 1;
                    while (c3 < mSatellites.length) {
                        Triangle triangle = Triangle.instantiateFromSatellites(
                                mSatellites[c1], mSatellites[c2], mSatellites[c3]);
                        if (triangle != null) {
                            pList.add(triangle.calculateCenter());
                        }
                        c3++;
                    }
                    c2++;
                }
                c1++;
            }
        }

        double sumX = 0, sumY = 0;
        for(Point<Double, Double> point : pList ) {
            sumX += point.getKey();
            sumY += point.getValue();
        }

        return new Point<Double, Double>(sumX/pList.size(), sumY/pList.size());
    }
}

class SeqGen extends RecursiveAction {
    int mStart;
    int mEnd;
    MessageDigest md5;

    public SeqGen(int start, int end) {
        mStart = start;
        mEnd = end;
        try {
            md5 = MessageDigest.getInstance("MD5");
        } catch (NoSuchAlgorithmException e) {
            System.exit(0);
        }
    }

    @Override
    protected void compute() {
        if ((mEnd - mStart) < GpsCalculator.THRESHOLD) {
            byte[] array = new byte[mEnd - mStart];
            for (int pos = mStart; pos < mEnd; pos++) {
                byte[] hash = md5.digest((GpsCalculator.PI + String.valueOf(((pos)))).getBytes());
                if (hash[0] < 0) {
                    array[pos-mStart] = 49;
                } else {
                    array[pos-mStart] = 48;
                }
            }
            System.arraycopy(array, 0, GpsCalculator.seq, mStart, array.length);
        } else {
            int middle = (mStart + mEnd) / 2;

            SeqGen subTaskA = new SeqGen(mStart, middle);
            SeqGen subTaskB = new SeqGen(middle, mEnd);

            invokeAll(subTaskA, subTaskB);
        }
    }
}

class Satellite {
    Point<Double, Double> mPosition;
    int mOffset;
    double mDistance;

    Satellite(double x, double y, byte[] seq) {
        mPosition = new Point<Double, Double>(x, y);
        mOffset = calculateOffset(seq);
        mDistance = calculateDistance(seq);
    }

    private int calculateOffset(byte[] seq) {
        int count = 1;
        while (seq[count] == seq[count - 1]) {
            count++;
        }

        if(count < 10) {
            return count;
        } else {
            return count%10;
        }
    }

    private int  findLongestChainOffset(byte[] seq) {
        int seqLength = seq.length;
        int offset = 0;
        int count = 1;
        int max = 0;
        //Offset 637 548 it will never go over border (1 000 000), because 27 000 km is about 100 000 units
        for(int i = mOffset + GpsCalculator.LONGEST_CHAIN_OFFSET*10; i < seqLength; i += 10) {
            if (seq[i] == seq[i - 10]) {
                count++;
            } else {
                if (count > max) {
                    max = count;
                    offset = i/10 - count;
                    if(max == GpsCalculator.LONGEST_CHAIN.length) {
                        break;
                    }
                }
                count = 1;
            }
        }
        return  offset;
    }

    private double calculateDistance(byte[] seq) {
         return ((findLongestChainOffset(seq) - GpsCalculator.LONGEST_CHAIN_OFFSET )*10 + mOffset)*GpsCalculator.UNIT_DISTANCE;
    }
}

class Triangle {
    Point<Double, Double> mVertex1;
    Point<Double, Double> mVertex2;
    Point<Double, Double> mVertex3;

    public static Triangle instantiateFromSatellites(Satellite sat1, Satellite sat2, Satellite sat3) {
        Point<Double, Double> p12 = calculateTwoSatelliteIntersection(sat1, sat2);
        Point<Double, Double> p21 = calculateTwoSatelliteIntersection(sat2, sat1);
        Point<Double, Double> p13 = calculateTwoSatelliteIntersection(sat1, sat3);
        Point<Double, Double> p31 = calculateTwoSatelliteIntersection(sat3, sat1);
        Point<Double, Double> p23 = calculateTwoSatelliteIntersection(sat2, sat3);
        Point<Double, Double> p32 = calculateTwoSatelliteIntersection(sat3, sat2);

        try {
            double xDiff1 = Math.abs(p12.getKey() - p13.getKey());
            double xDiff2 = Math.abs(p12.getKey() - p31.getKey());
            double xDiff3 = Math.abs(p21.getKey() - p13.getKey());
            double xDiff4 = Math.abs(p21.getKey() - p31.getKey());

            double xDiff5 = Math.abs(p12.getKey() - p23.getKey());
            double xDiff6 = Math.abs(p12.getKey() - p32.getKey());
            double xDiff7 = Math.abs(p21.getKey() - p23.getKey());
            double xDiff8 = Math.abs(p21.getKey() - p32.getKey());

            Point<Double, Double> vertex1, vertex2, vertex3;

            if(Math.min(xDiff1, xDiff2) < Math.min(xDiff3, xDiff4)) {
                vertex1 = p12;
                if(xDiff1 < xDiff2) {
                    vertex2 = p13;
                } else {
                    vertex2 = p31;
                }
                if(xDiff5 < xDiff6) {
                    vertex3 = p23;
                } else {
                    vertex3 = p32;
                }
            } else {
                vertex1 = p21;
                if(xDiff3 < xDiff4) {
                    vertex2 = p13;
                } else {
                    vertex2 = p31;
                }
                if(xDiff7 < xDiff8) {
                    vertex3 = p23;
                } else {
                    vertex3 = p32;
                }
            }

            return new Triangle(vertex1, vertex2, vertex3);
        } catch (NullPointerException e) {
            return null; // if one or more point invalid
        }
    }

    private Triangle (Point<Double, Double> vertex1,
                     Point<Double, Double> vertex2,
                     Point<Double, Double> vertex3) {
        mVertex1 = vertex1;
        mVertex2 = vertex2;
        mVertex3 = vertex3;
    }

    public static Point<Double, Double> calculateTwoSatelliteIntersection(Satellite sat1, Satellite sat2) {
        double x1 = sat1.mPosition.getKey();
        double y1 = sat1.mPosition.getValue();
        double x2 = sat2.mPosition.getKey();
        double y2 = sat2.mPosition.getValue();

        double r1 = sat1.mDistance;
        double r2 = sat2.mDistance;

        double xDiff = x2 - x1;
        double yDiff = y2 - y1;
        double dist = Math.sqrt(Math.pow(xDiff,2) + Math.pow(yDiff,2));

        if (dist > (r1 + r2 + 50)) {
            return null;
        } else if (dist < Math.abs(r1 - r2)) {
            return null;
        } else if((r1 + r2) <= dist && dist <= (r1 + r2 + 50)) {
            r1 = dist - r2;
        }

        double k = (Math.pow(dist, 2) + Math.pow(r1, 2) - Math.pow(r2, 2)) / (2 * dist);

        double x = x1 + xDiff * k / dist + (yDiff / dist) * Math.sqrt(Math.pow(r1, 2) - Math.pow(k, 2));
        double y = y1 + yDiff * k / dist - (xDiff / dist) * Math.sqrt(Math.pow(r1, 2) - Math.pow(k, 2));

        return new Point<Double, Double>(x, y);
    }

    public Point<Double, Double> calculateCenter() {
        try {
            double x = (mVertex1.getKey() + mVertex2.getKey() + mVertex3.getKey())/3;
            double y = (mVertex1.getValue() + mVertex2.getValue() + mVertex3.getValue())/3;

            return new Point<Double, Double>(x,y);
        } catch (NullPointerException e) {
            return null; //If triangle creation failed
        }
    }
}

class Point<K,V> {
    private K mKey;
    private V mValue;

    public Point(K key, V value) {
        mKey = key;
        mValue = value;
    }

    public K getKey() {
        return mKey;
    }

    public V getValue() {
        return mValue;
    }

}
