//@Staker
import java.io.BufferedInputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class Staker {
  static final double M_PER_TICK = 29.9792458;
  static final double TICK_PER_M = 0.03335640951;
  static final double MAX_RANGE = 6378000;
  static final int MINIMUM_READ_SKIP = 120800;
  static final int MAX_READ_SIZE = 885000;
  static final int SEQ_SIZE = 10000001;
  static final int APPROXIMATION_MARGIN = 50;
  static final String START_COMPACT = "111001100011101101";
  static final Pattern START_COMPACT_PATTERN = Pattern.compile(START_COMPACT, Pattern.LITERAL);
  static byte[] buf = new byte[SEQ_SIZE];

  static long startTime = 0;
  static volatile boolean stop = false;
  static volatile boolean stopReader = false;
  
  static volatile Solution approximation = null;

  static class Satelite {
    static final double HALFTICK_MARGIN = 0.001;
    static final double HALFTICK = 14.9896229;
    static final double HALFTICK_ALLOWED_RANGE = HALFTICK + 0.002;

    int index;
    double x;
    double y;
    double range;
    double checkRange;
    
    Satelite(double x, double y, double range) {
      this(-1, x, y, range);
    }
    
    Satelite(int index, double x, double y, double range) {
	    this.index = index;
	    this.x = x;
	    this.y = y;
	    this.range = range;
	  }
	  
	  double scoreSolution(Solution s) {
	    double solutionRange = range(x, y, s.x, s.y);
	    double score = 1;
	    double delta = Math.abs(range - solutionRange);
      if (delta > HALFTICK_ALLOWED_RANGE) {
        double tempScore = 1/(1 + delta - HALFTICK_ALLOWED_RANGE);
        if (tempScore < score) {
          score = tempScore;
        }
      }
	    return score;  
	  }
	  
	  Satelite halfTickCloser() {;
	    return new Satelite(x, y, range - HALFTICK + HALFTICK_MARGIN);
	  }
    Satelite halfTickFarther() {
      return new Satelite(x, y, range + HALFTICK - HALFTICK_MARGIN);
    }
  }
  
  static class Solution {
    double x;
    double y;
    double score;
    double spread;
    double count;
    Solution(double x, double y) {
      this.x = x;
      this.y = y;
      this.score = 0;
      this.spread = 0;
      this.count = 0;
    }
    Solution(Solution other) {
      this.x = other.x;
      this.y = other.y;
      this.score = other.score;
      this.spread = other.spread;
      this.count = other.count;
    }
    boolean check() {
      return range(0, 0, x, y) <= MAX_RANGE;
    }
  }
  
  static class Buffer extends Object implements CharSequence {
    final byte[] byteBuf;
    final int offset;
    final int len;
    
    Buffer(byte[] buf, int offset, int len) {
      this.offset = offset;
      this.len = len;
      this.byteBuf = buf;
    }
    @Override
    public char charAt(int arg0) {
      return (char)byteBuf[offset + arg0 * 10];
    }

    @Override
    public int length() {
      return len / 10;
    }

    @Override
    public CharSequence subSequence(int arg0, int arg1) {
      return null;
    }
    
  }
  static double range(double x1, double y1, double x2, double y2) {
    return Math.sqrt((x2-x1)*(x2-x1) + (y2-y1)*(y2-y1));
  }
  
  static ArrayList<Solution> calc(Satelite s1, Satelite s2) {
    ArrayList<Solution> result = new ArrayList<Solution>();
    double xT = s2.x - s1.x;  
    double yT = s2.y - s1.y;
    double theta = Math.atan2(yT, xT);
    double d = Math.sqrt(xT*xT + yT*yT);
    double resX = (s1.range*s1.range - s2.range*s2.range + d*d)/(2*d);
    double resY = Math.sqrt(s1.range*s1.range - resX*resX);
    //System.out.format("Solution [%e %e]\n", resX, resY);

    double resR = Math.sqrt(resX*resX + resY*resY);
    double resT1 = Math.atan2(resY, resX) + theta;
    double resT2 = Math.atan2(-resY, resX) + theta;
    double finalX1 = resR*Math.cos(resT1) + s1.x;
    double finalY1 = resR*Math.sin(resT1) + s1.y;
    double finalX2 = resR*Math.cos(resT2) + s1.x;
    double finalY2 = resR*Math.sin(resT2) + s1.y;
    Solution solution = new Solution(finalX1, finalY1);
    if (solution.check()) {
      result.add(solution);
    }
    solution = new Solution(finalX2, finalY2);
    if (solution.check()) {
      result.add(solution);
    }
    return result;
  }
  
  static int indexOf(byte[] buf, int len, byte[] pattern) {
    for (int i = 0; i < len - pattern.length; ++i) {
      int j;
      for (j = 0; j < pattern.length; ++j) {
        if (buf[i + j] != pattern[j]) {
          break;
        }
      }
      if (j == pattern.length) {
        return i;
      }
    }

    return -1;
  }
  
  static Satelite readSatelite(BufferedInputStream in, Solution approximation, int index) throws IOException {
    double x = Double.parseDouble(readLine(in));
    double y = Double.parseDouble(readLine(in));
    in.read(buf, 0, SEQ_SIZE);
    // Handle \r\n EOL.
    if (buf[SEQ_SIZE - 1] == '\r') {
      in.mark(3);
      int c = in.read();
      if (c != '\n') {
        in.reset();
      }
    }
    double satOriginDistance = range(0, 0, x, y);
    int headSkipSize = (int)((satOriginDistance - MAX_RANGE) * TICK_PER_M);
    headSkipSize -= (headSkipSize % 10);
    int readSize = MAX_READ_SIZE;
    boolean seen0 = false, seen1 = false;
    int shift = -1;
    while (!seen0 || ! seen1) {
      ++shift;
      if (buf[shift] == '0') seen0 = true;
      if (buf[shift] == '1') seen1 = true;
    }
    shift = shift % 10;

    if (approximation != null) {
      double approximateRange = range(x, y, approximation.x, approximation.y);
      headSkipSize = (int)(approximateRange * TICK_PER_M - APPROXIMATION_MARGIN);
      headSkipSize -= (headSkipSize % 10);
      readSize = 2 * APPROXIMATION_MARGIN + START_COMPACT.length() * 10;
    }
    headSkipSize += shift;
    Buffer seq = new Buffer(buf, headSkipSize, readSize);
    Matcher matcher = START_COMPACT_PATTERN.matcher(seq);
    if (!matcher.find()) {
      headSkipSize = MINIMUM_READ_SKIP + shift;
      seq = new Buffer(buf, headSkipSize, MAX_READ_SIZE);
      matcher.reset(seq);
      matcher.find();
    }
    int ind = matcher.start() * 10 + headSkipSize;

    return new Satelite(index, x, y, ind * M_PER_TICK);   
  }

  static boolean checkSpread(ArrayList<Solution> solutions) {
    if (solutions.size() < 2) return false;
    final double MAX_SPREAD = 400;
    double minX, minY, maxX, maxY;
    minX = minY = 10000000;
    maxX = maxY = -10000000;
    for (Solution sol : solutions) {
      if (sol.x > maxX) maxX = sol.x;
      if (sol.y > maxY) maxY = sol.y;
      if (sol.x < minX) minX = sol.x;
      if (sol.y < minY) minY = sol.y;
    }
    return range(minX, minY, maxX, maxY) < MAX_SPREAD;
  }

  static ArrayList<Solution> pickSingleCluster(ArrayList<Solution> solutions) {
    final double MAX_SPREAD = 400;
    // Calculate mean only for solutions close to solution 1. 
    Solution s1 = solutions.get(0);
    ArrayList<Solution> result = new ArrayList<Solution>();
    result.add(s1);
    for (Solution sol : solutions) {
      if (sol == s1) continue;
      if (range(s1.x, s1.y, sol.x, sol.y) < MAX_SPREAD) {
        result.add(sol);
      }
    }
    return result;    
  }

  static Solution calculateApproximation(ArrayList<Solution> solutions) {
    double totalX = 0, totalY = 0;
    double minX, minY, maxX, maxY;
    minX = minY = 10000000;
    maxX = maxY = -10000000;
    for (Solution sol : solutions) {
      totalX += sol.x;
      totalY += sol.y;
      if (sol.x > maxX) maxX = sol.x;
      if (sol.y > maxY) maxY = sol.y;
      if (sol.x < minX) minX = sol.x;
      if (sol.y < minY) minY = sol.y;
    }
    Solution sol = new Solution(totalX/solutions.size(), totalY/solutions.size());
    sol.spread = range(minX, minY, maxX, maxY);
    sol.count = Math.pow(solutions.size(), 0.25);
    return sol;
  }

  static ArrayList<Solution> getSolutionGrid(double x, double y, double stepX, double stepY,
      ArrayList<Satelite> sateliteList) {
    ArrayList<Solution> areaSolutions = new ArrayList<Solution>(11*11);
    for (double xx = x - stepX*5; xx <= x + stepX*5.5; xx += stepX) {
      for (double yy = y - stepY*5; yy <= y + stepY*5.5; yy += stepY) {
        areaSolutions.add(new Solution(xx, yy));
      }
    }
    return filterResults(areaSolutions, sateliteList);
  }

  static Solution calculateSolution(Solution approximation, ArrayList<Satelite> sateliteList) {   
    double step = 10;
    ArrayList<Solution> areaSolutions;
    Solution current = approximation;
    do {
      areaSolutions = getSolutionGrid(current.x, current.y, step, step, sateliteList);
      if (areaSolutions.size() == 1 && current.score < 1 && areaSolutions.get(0).score > current.score) {
        // Found a better single approximation point.
        current = areaSolutions.get(0);          
      } else {
        step /= 2;
        current = calculateApproximation(areaSolutions);
      }
    } while (areaSolutions.size() < 20 && step > 0.01);
    return current;
  }
  
  static void findSolutions(
      int startIndex, ArrayList<Satelite> sateliteList, ArrayList<Solution> result) {
    for (Satelite sat1 : sateliteList) {
      for (Satelite sat2 : sateliteList) {
        if (sat2.index <= sat1.index || sat2.index < startIndex) {
          continue;
        }
        result.addAll(calc(sat1, sat2));
        result.addAll(calc(sat1.halfTickCloser(), sat2));
        result.addAll(calc(sat1.halfTickFarther(), sat2));
        
        result.addAll(calc(sat1, sat2.halfTickCloser()));
        result.addAll(calc(sat1.halfTickCloser(), sat2.halfTickCloser()));
        result.addAll(calc(sat1.halfTickFarther(), sat2.halfTickCloser()));
        
        result.addAll(calc(sat1, sat2.halfTickFarther()));
        result.addAll(calc(sat1.halfTickCloser(), sat2.halfTickFarther()));
        result.addAll(calc(sat1.halfTickFarther(), sat2.halfTickFarther()));
      }
    }
  }
  
  static ArrayList<Solution> filterResults(
      ArrayList<Solution> solutions, ArrayList<Satelite> sateliteList) {
    ArrayList<Solution> result = new ArrayList<Solution>();
    Solution approximation = null;
    double bestScore = 0;
    for (Solution sol : solutions) {
      double minScore = 1;
      for (Satelite satelite : sateliteList) {
        double score = satelite.scoreSolution(sol);
        if (score < minScore) {
          minScore = score;
        }
      }
      if (minScore > bestScore) {
        bestScore = minScore;
        approximation = sol;
      }
      if (minScore == 1) {
        result.add(sol);
        sol.score = 1;
      }
    }
    if (approximation != null && result.size() == 0) {
      result.add(approximation);
      approximation.score = bestScore;
    }
    return result;
  }
  
  static String readLine(BufferedInputStream in) throws IOException {
    StringBuilder result = new StringBuilder();
    int c = in.read();
    while (c >=0 && c != '\n' && c != '\r') {
      result.append(Character.toChars(c));
      c = in.read();
    }
    if (c == '\r') {
      in.mark(3);
      int tmp = in.read();
      if (tmp != '\n') {
        in.reset();
      }
    }
    return result.toString();
  }
  static class SateliteReader extends Thread {
    LinkedBlockingQueue<Satelite> satelites;
    BufferedInputStream in;
    volatile int numSats = 0;
    
    SateliteReader(LinkedBlockingQueue<Satelite> satelites) {
      this.satelites = satelites;
    }
    @Override
    public void run() {
      try {
        BufferedInputStream in = new BufferedInputStream(System.in);
        numSats = Integer.parseInt(readLine(in));
        for (int i = 0; i < numSats && !stopReader; ++i) {
          satelites.add(readSatelite(in, approximation, i));
        }
        if (stopReader) {
          satelites.add(new Satelite(-1, 0, 0, 0));
        }
        in.close();
      } catch (NumberFormatException e) {
        e.printStackTrace();
      } catch (IOException e) {
        e.printStackTrace();
      }
    }
  }

  static class Scorer extends Thread {
    volatile ArrayList<Satelite> sateliteList;
    ArrayList<Solution> result;
    LinkedBlockingQueue<Satelite> scoreSatelites;
    
    Scorer(ArrayList<Satelite> sateliteList, ArrayList<Solution> result,
        LinkedBlockingQueue<Satelite> scoreSatelites) {
      this.sateliteList = sateliteList;
      this.result = result;
      this.scoreSatelites = scoreSatelites;
    }

    @Override
    public void run() {
      ArrayList<Satelite> localSateliteList = new ArrayList<Satelite>();
      while (!stop) {
        scoreSatelites.drainTo(localSateliteList);
        Solution localApproximation = new Solution(approximation); 
        localApproximation = calculateSolution(localApproximation, localSateliteList);
        approximation = localApproximation;
        Satelite sat = null;
        try {
          sat = scoreSatelites.take();
        } catch (InterruptedException e) {
          return;
        }
        localSateliteList.add(sat);
      }
      stopReader = true;
    }
  }

  static class ScoringDaemon extends Thread {

    ScoringDaemon() {
    }

    @Override
    public void run() {
      double pScore = 0;
      while (true) {
        try {
          Thread.sleep(0, 10000);
        } catch (InterruptedException e) {
          return;
        }
        long currTime = System.nanoTime();
        long timePassed = currTime - startTime;
        double tScore = 10/(timePassed/1000000000.0 + 1.1);
        double curPScore;
        if (approximation == null) {
          curPScore = 0;
        } else if (approximation.spread > 1000) {
          curPScore = 0;
        } else if (approximation.spread > 0) {
          curPScore = 100/(approximation.spread/2.2 + 10);
        } else {
          curPScore = 100/(1/approximation.score+10.01);
        }
        if (curPScore > pScore) {
          pScore = curPScore;
        }
        if (pScore > 0 && timePassed > 4800000000L) {
          stop = true;
        } else if (pScore > tScore) {
          // Good time-precision balance. Stop on next iteration.
          stop = true;
        }
        if (stop) {
          return;
        }
        if (timePassed > 4900000000L) {
          // We have some score and 4.9 seconds passed. Stop now! 
          complete();
        }
      }
    }
  }

  static void complete() {
    if (approximation != null) {
      System.out.format("%f %f", approximation.x, approximation.y);
    } else {
      System.out.print("0 0");
    }
    System.exit(0);
  }

  public static void main(String[] args) throws IOException, InterruptedException{
    startTime = System.nanoTime();
    LinkedBlockingQueue<Satelite> readSatelites = new LinkedBlockingQueue<Satelite>();
    LinkedBlockingQueue<Satelite> scoreSatelites = new LinkedBlockingQueue<Satelite>();
    SateliteReader sateliteReader = new SateliteReader(readSatelites);
    sateliteReader.start();
    //System.setIn(new FileInputStream("/media/ramdisk/test3_hi_precision.in"));
    //BufferedReader in = new BufferedReader(new InputStreamReader(System.in));

    while (sateliteReader.numSats == 0) {
      Thread.sleep(0, 1000);
    }
    int numSats = sateliteReader.numSats;
    ArrayList<Satelite> sateliteList = new ArrayList<Satelite>();
    ArrayList<Solution> result = new ArrayList<Solution>();
    Scorer scorer = new Scorer(sateliteList, result, scoreSatelites);
    ScoringDaemon scoringDaemon = new ScoringDaemon();
    int startIndex = 0;
    while (sateliteList.size() < numSats && !stopReader) {
      Satelite sat = readSatelites.take();
      if (stopReader) break;
      sateliteList.add(sat);
      scoreSatelites.add(sat);
      if (sateliteList.size() > 1 && approximation == null) {
        findSolutions(startIndex, sateliteList, result);
        startIndex = sateliteList.size();
        result = filterResults(result, sateliteList);
        if (checkSpread(result)) {
          approximation = calculateApproximation(result);
          if (numSats > 2) {
            scorer.start();
            scoringDaemon.start();
          }
        }
      }
    }
    scorer.interrupt();
    if (approximation == null) {
      result = pickSingleCluster(result);
      approximation = calculateApproximation(result);
    }
    approximation = calculateSolution(approximation, sateliteList);
    
    complete();
  }
}