//@cab404

import java.awt.geom.Area;
import java.awt.geom.Ellipse2D;
import java.io.*;
import java.nio.charset.Charset;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;


/**
 * @author cab404
 */
public class Navigation {

    private static final String absolutely_random =
            "3.141592653589793238462643383279" +
                    "502884197169399375105820" +
                    "974944592307816406286208" +
                    "998628034825342117067982" +
                    "1480865132823066470938446";

    private static final double
            C = 299792458f;

    private static final int
            PLANET_R = 6378000;

    private static final int
            // Наименьший размер уникального пакета, т.е для любой выборки
            // из массива не будет повторяющихся последовательностей.
            // Число взято не с потолка, вся последовательность была проверена на повторы.
            // Могу выслать анализатор.
            CUT_PACKET_TO = 40;


    private static MessageDigest md;
    static {
        try {
            md = MessageDigest.getInstance("MD5");
        } catch (NoSuchAlgorithmException e) {
            throw new RuntimeException();
        }
    }
    private static String md5(String str) {

        StringBuilder hash = new StringBuilder();
        for (byte b : md.digest(str.getBytes(Charset.forName("UTF-8")))) {
            hash.append(byteToString(b));
        }

        return hash.toString();
    }
    private static String byteToString(byte b) {
        String ready = Integer.toString(255 & b, 16);
        if (ready.length() == 1)
            return '0' + ready;
        return ready;
    }


    /**
     * Читает сигнал. Мы не используем все данные, это позволяет сэкономить память и время чтения.
     */
    private static Signal readPacket(Reader in)
            throws IOException {
        BufferedReader reader = new BufferedReader(in);
        Signal signal = new Signal();

        int counter = 10;
        int data_index = 0;

        for (int i = 0; i < signal.data.length * 10; i++) {
            int ch = reader.read();

            if (data_index == signal.data.length)
                break;

            boolean entry = (char) ch == '1';

            if (counter == 10) {
                signal.data[data_index++] = entry;
                counter = 0;
            } else if (signal.data[data_index - 1] != entry) {
                signal.data[data_index++] = entry;
                signal.offset = 10 - counter;
                counter = 0;
            }
            counter++;

        }

        reader.close();
        return signal;
    }

    /**
     * Ищет последовательность what в массиве where.
     */
    private static int cyclicSearch(boolean[] where, boolean[] what) {
        search_start:
        for (int i = 0; i < where.length; i++) {
            for (int j = 0; j < what.length; j++) {
                if (where[(i + j) % where.length] != what[j]) {
                    continue search_start;
                }
            }
            return i;
        }
        throw new RuntimeException();
    }

    // === main ===

    public static void main(String[] args)
    throws Throwable {
        final boolean[] cached = new boolean[1000000];

        LineNumberReader in = new LineNumberReader(
                new InputStreamReader(System.in)
//                new FileReader("test1.in")
        );

        // Вычисляем последовательность.
        for (int pos = 0; pos < 1000000; pos++)
            cached[pos] = md5(absolutely_random + pos).charAt(0) > '7';

        // Считываем все координаты, вычисляем расстояния.
        int num = Integer.parseInt(in.readLine());
        final ArrayList<Satellite> satellites = new ArrayList<>(num);

        for (int i = 0; i < num; i++) {
            final Satellite satellite = new Satellite();

            satellite.pos.x = Double.parseDouble(in.readLine());
            satellite.pos.y = Double.parseDouble(in.readLine());

            char[] chars = new char[CUT_PACKET_TO * 10];
            in.read(chars, 0, chars.length);
            in.skip(10000000 - chars.length);

            int line = in.getLineNumber();
            while (in.getLineNumber() == line) in.skip(1);
            final Signal signal = readPacket(new StringReader(String.valueOf(chars)));


            int offset = cyclicSearch(cached, signal.data) * 10 + signal.offset;
            satellite.distance = (10000000 - offset) * (C / 10000000f);
            satellites.add(satellite);
        }

        in.close();

        // Вычисляем пересечение всех зон действия спутников и планеты.

        Area area = new Area(
                new Ellipse2D.Double(
                        - PLANET_R,
                        - PLANET_R,
                        PLANET_R * 2,
                        PLANET_R * 2
                )
        );

        for (Satellite s : satellites) {
            area.intersect(new Area(new Ellipse2D.Double(
                    s.pos.x - s.distance,
                    s.pos.y - s.distance,
                    s.distance * 2, s.distance * 2
            )));
        }

        // Выдаём центр этой зоны.
        System.out.println(area.getBounds2D().getCenterX() + " " + area.getBounds2D().getCenterY());

    }

    // === Вспомогательные классы ===

    private static class Satellite {
        double distance;
        final Vector pos = new Vector();
    }

    private static class Signal {
        final boolean[] data = new boolean[CUT_PACKET_TO];
        int offset;
    }

    private static class Vector {
        double x, y;
    }
}
