//@cdar
import java.io.*;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.*;

public class Main {

    private static final long SPEED = 299792458L;
    private static final double RADIUS = 6378_000d;
    private static final int OFFSET_18 = 427400;
    private static final int OFFSET_19 = 6375480;
    private static final long EPSILON = 10_000L;

    public static void main(String[] args) throws Exception {
        read(System.in);
    }

    private static void read(InputStream in) throws Exception {
        List<Point> points = new ArrayList<>();

        String subSrt19 = generateSubstring19();
        String subSrt18 = generateSubstring18();

        BufferedReader br = new BufferedReader(new InputStreamReader(in));

        String line = br.readLine();
        int satellites = Integer.valueOf(line);

        CalcParams params = new CalcParams();
        for (int i=0; i<satellites; i++) {
            line = br.readLine();
            BigDecimal x = new BigDecimal(line);
            line = br.readLine();
            BigDecimal y = new BigDecimal(line);

            line = br.readLine();

            BigDecimal radius = findRadius(subSrt19, subSrt18, line);

            if ((i+1)%2==1) {
                params.x1=x;
                params.y1=y;
                params.r1=radius;
            }
            else {
                params.x2=x;
                params.y2=y;
                params.r2=radius;
            }

            if (i>0) {
                calculate(params, points);
            }
        }

        Point point = findCrossPoint(points);
        System.out.println(point.x.setScale(3, RoundingMode.HALF_UP).toString() + " " + point.y.setScale(3, RoundingMode.HALF_UP));

        br.close();
    }

    private static String generateSubstring18() {
        StringBuilder sb = new StringBuilder(182);
        sb.append('1');
        for (int i=0; i<18; i++) {
            sb.append("0000000000");
        }
        sb.append('1');
        return sb.toString();
    }

    private static String generateSubstring19() {
        StringBuilder sb = new StringBuilder(192);
        sb.append('0');
        for (int i=0; i<19; i++) {
            sb.append("1111111111");
        }
        sb.append('0');
        return sb.toString();
    }

    private static BigDecimal findRadius(String subStr19, String subStr18, String line) {
        BigDecimal radius = BigDecimal.ZERO;
        int subStr18Index = line.indexOf(subStr18, OFFSET_18);
        if (subStr18Index>0) {
            radius = BigDecimal.valueOf(subStr18Index - OFFSET_18)
                    .multiply(BigDecimal.valueOf(SPEED))
                    .divide(BigDecimal.valueOf(10_000_000), RoundingMode.HALF_UP);
        }
        else  {
            int subStr19Index = line.indexOf(subStr19, OFFSET_19);
            if (subStr19Index>0) {
                radius = BigDecimal.valueOf(subStr19Index - OFFSET_19)
                        .multiply(BigDecimal.valueOf(SPEED))
                        .divide(BigDecimal.valueOf(10_000_000), RoundingMode.HALF_UP);
            }
        }
        return radius;
    }

    private static void calculate(CalcParams p, List<Point> points) {
        BigDecimal x2 = p.x2.subtract(p.x1),
                y2 = p.y2.subtract(p.y1);

        BigDecimal r1 = p.r1;
        BigDecimal r2 = p.r2;

        BigDecimal c = r2.multiply(r2)
                .subtract(x2.multiply(x2))
                .subtract(y2.multiply(y2))
                .subtract(r1.multiply(r1))
                .divide(BigDecimal.valueOf(-2), RoundingMode.HALF_UP);
        BigDecimal a = x2.multiply(x2).add(y2.multiply(y2));
        BigDecimal b = y2.multiply(c).multiply(BigDecimal.valueOf(-2));
        BigDecimal e = c.multiply(c).subtract(r1.multiply(r1).multiply(x2).multiply(x2));
        BigDecimal D = b.multiply(b).subtract(a.multiply(e).multiply(BigDecimal.valueOf(4)));

        if (D.doubleValue()>=0) {
            BigDecimal Dsqrt = BigDecimal.valueOf(Math.sqrt(D.doubleValue()));

            BigDecimal y1r = BigDecimal.ZERO.subtract(b)
                    .add(Dsqrt)
                    .divide(a, RoundingMode.HALF_UP)
                    .divide(BigDecimal.valueOf(2), RoundingMode.HALF_UP);
            BigDecimal y2r = BigDecimal.ZERO.subtract(b)
                    .subtract(Dsqrt)
                    .divide(a, RoundingMode.HALF_UP)
                    .divide(BigDecimal.valueOf(2), RoundingMode.HALF_UP);
            BigDecimal x1r = c.subtract(y1r.multiply(y2)).divide(x2, RoundingMode.HALF_UP);
            BigDecimal x2r = c.subtract(y2r.multiply(y2)).divide(x2, RoundingMode.HALF_UP);

            x1r = x1r.add(p.x1);
            x2r = x2r.add(p.x1);
            y1r = y1r.add(p.y1);
            y2r = y2r.add(p.y1);

            addPointIfInside(points, x1r, y1r);
            addPointIfInside(points, x2r, y2r);
        }
    }

    private static void addPointIfInside(List<Point> points, BigDecimal x, BigDecimal y) {
        boolean inside = x.doubleValue() < RADIUS && y.doubleValue() < RADIUS &&
                Math.sqrt(x.multiply(x).add(y.multiply(y)).doubleValue()) < RADIUS;
        if (inside) {
            points.add(new Point(x, y));
        }
    }

    private static Point findCrossPoint(List<Point> points) {
        List<Pair<Point, Integer>> priorityList = new ArrayList<>();
        for (Point point : points) {
            addToPriorityList(point, priorityList);
        }

        Collections.sort(priorityList, new Comparator<Pair<Point, Integer>>() {
            @Override
            public int compare(Pair<Point, Integer> o1, Pair<Point, Integer> o2) {
                return o2.getValue().compareTo(o1.getValue());
            }
        });

        return priorityList.get(0).getKey();
    }

    private static void addToPriorityList(Point newPoint, List<Pair<Point, Integer>> priorityList) {
        Pair<Point,Integer> pairToAdd = null;
        Iterator<Pair<Point,Integer>> iterator = priorityList.iterator();
        while (iterator.hasNext()) {
            Pair<Point, Integer> next = iterator.next();
            Point point = next.getKey();
            boolean near = Math.abs(point.x.subtract(newPoint.x).doubleValue()) < EPSILON &&
                    Math.abs(point.y.subtract(newPoint.y).doubleValue()) < EPSILON;
            if (near) {
                Point pointToAdd = new Point(
                        point.x.add(newPoint.x).divide(BigDecimal.valueOf(2), RoundingMode.HALF_UP),
                        point.y.add(newPoint.y).divide(BigDecimal.valueOf(2), RoundingMode.HALF_UP));
                pairToAdd = new Pair<>(pointToAdd, next.getValue()+1);
                iterator.remove();
                break;
            }
        }

        if (pairToAdd == null) {
           pairToAdd = new Pair<>(newPoint, 1);
        }

        priorityList.add(pairToAdd);
    }


    private static class CalcParams {
        BigDecimal x1, y1, x2, y2;
        BigDecimal r1, r2;
    }

    private static class Point {
        BigDecimal x, y;

        private Point(BigDecimal x, BigDecimal y) {
            this.x = x;
            this.y = y;
        }
    }

    private static class Pair<K, V> {
        private K key;
        private V value;

        private Pair(K key, V value) {
            this.key = key;
            this.value = value;
        }

        private K getKey() {
            return key;
        }

        private V getValue() {
            return value;
        }
    }
}