//@conterouz

import java.io.*;
import java.util.*;

import static java.lang.Math.min;
import static java.lang.Math.sqrt;
import static java.lang.System.*;

public class Glonass2063 {
    static final String magic_seq = "01000110111000100010"; // hehe, this is uniq tail (20 bits) of seq;

    static final double tick = 299792458.0/1000000;
    static final double subtick = tick/10;
    static final double err = subtick/2;
    static final double mindist = 6378000.0;
    static final double around = subtick;

    static final int SEQLEN = 1000000;
    static final int SEQLEN10 = SEQLEN*10;
    static final int NEED = 88000;
    static final int NEED10 = NEED*10;

    static class Sat {
        Point p;
        String seq;
        int subshift;
        double dist;

        Sat(double x, double y) {
            p = new Point(x, y);
        }

        double dist(Sat s) {
            return p.dist(s.p);
        }

        //TODO: REMOVE
        @Override
        public String toString() {
            return p.toString() + "[" + subshift + "]" + "{" + dist + "}";
        }

    }

    static class Point implements Comparable<Point>{
        double x;
        double y;

        Point(double x, double y) {
            this.x = x;
            this.y = y;
        }

        boolean check() {
            return dist(0, 0) < mindist;
        }

        double dist(double x1, double y1) {
            return sqrt(sq(x-x1) + sq(y-y1));
        }

        double dist(Point p) {
            return dist(p.x, p.y);
        }

        boolean near(Point p) {
            return dist(p) < around;
        }

        @Override
        public int compareTo(Point o) {
            int xd = (int)(x - o.x);
            if (xd == 0) {
                return (int)(y - o.y);
            } else {
                return xd;
            }
        }

        @Override
        public String toString() {
            return "(" + x + ", "  + y + ")";
        }
    }

    static class Tri implements Comparable<Tri>{
        Sat s1, s2, s3;
        double sq;

        Tri(Sat s1, Sat s2, Sat s3) {
            this.s1 = s1;
            this.s2 = s2;
            this.s3 = s3;
            this.sq = trian(s1, s2, s3);
        }

        @Override
        public int compareTo(Tri t) {
            return (int)(t.sq - sq);
        }
    }

    static Point g;
    public static void main(String[] args) throws IOException {
        new Glonass2063().run();
    }

    void run() throws IOException {
        List<Sat> ls = readsats(in);

        List<Tri> top = top_triangles(ls, 100);

        List<Sat> sats = ls.size() == 2 ? ls : get_sats(top);

        calc_dists(sats);

        List<Point> ps = points(sats);

        for (int i = 0; i < 1; i++) {
            Point p = ps.get(i);
            out.println(p.x + " " + p.y + (g == null ? "" : " :: " + p.dist(g) + " " + g));
        }
    }

    static List<Point> points(List<Sat> ss) {
        List<Point> ps = new ArrayList<Point>();

        if (ss.size() == 2) {
            return circ_int2(ss.get(0), ss.get(1));
        } else {
            for (int i = 0; i < ss.size(); i++) {
                for (int j = i + 1; j < ss.size(); j++) {
                    ps.addAll(circ_int2(ss.get(i), ss.get(j)));
                }
            }
        }
        Collections.sort(ps);

        List<List<Point>> clusters = new ArrayList<List<Point>>();
        Point l = null;
        List<Point> acc = new ArrayList<Point>();
        for (Point p : ps) {
            if (l != null) {
                if (p.near(l)) {
                    acc.add(p);
                    l = center(acc);
                } else {
                    if (acc.size() > 1) {
                        clusters.add(new ArrayList<Point>(acc));
                    }
                    acc.clear();
                    l = p;
                    acc.add(p);
                }
            } else {
                l = p;
                acc.add(p);
            }
        }
        if (acc.size() > 1){
            clusters.add(acc);
        }
        Collections.sort(clusters, new Comparator<List<Point>>() {
            @Override
            public int compare(List<Point> o1, List<Point> o2) {
                return o2.size() - o1.size();
            }
        });
        List<Point> rr = new ArrayList<Point>();
        int max = 0;
        for (List<Point> cl : clusters) {
            if (cl.size() >= max) {
                rr.add(center(cl));
                max = cl.size();
            }
        }
        return rr;
    }

    static List<Tri> top_triangles(List<Sat> ls, int n) {
        List<Tri> ts = new ArrayList<Tri>();
        for (int i = 0; i < ls.size(); i++) {
            for (int j = i + 1; j < ls.size(); j++) {
                for (int k = j + 1; k < ls.size(); k++) {
                    ts.add(new Tri(ls.get(i), ls.get(j), ls.get(k)));
                }
            }
        }
        Collections.sort(ts);
        List<Tri> fts = ts.subList(0, min(ts.size(), n));
        return fts;
    }

    static List<Sat> get_sats(List<Tri> ts) {
        Set<Sat> satset = new HashSet<Sat>();
        for (Tri t : ts) {
            satset.add(t.s1);
            satset.add(t.s2);
            satset.add(t.s3);
        }
        return new ArrayList<Sat>(satset);
    }

    private static void calc_dists(List<Sat> ss) {
        List<Sat> toremove = new LinkedList<Sat>();
        for (int i = 0; i < ss.size(); i++) {
            Sat sat = ss.get(i);
            log("LEN: " + sat.seq.length() + " " + sat.seq.substring(0, 20) + ": " + sat.seq.substring(11100, 11120));
            int ticks = sat.seq.indexOf(magic_seq) + magic_seq.length();
            if (ticks < 0) toremove.add(sat);
            sat.dist = ticks * tick + sat.subshift*subtick + err;
            log("TCS:" + ticks + " SAT:" + sat);
        }
        ss.removeAll(toremove);
    }

    static List<Sat> readsats(InputStream is) throws IOException {
        long s = currentTimeMillis();
        BufferedReader rd = new BufferedReader(new InputStreamReader(is), 10000000);

        int count = Integer.parseInt(rd.readLine());
        List<Sat> ss = new ArrayList<Sat>(count);
        for (int i = 0; i < count; i++) {
            Sat sat = new Sat(Double.parseDouble(rd.readLine()), Double.parseDouble(rd.readLine()));
            readseq_fast(rd, sat);
            ss.add(sat);
            log(sat);
        }
        log("*reading " + (currentTimeMillis() - s));
        return ss;
    }

    static void log(Object o) {
        //System.out.println(o);
    }

    static Point center(List<Point> ps) {
        double mx = 0;
        double my = 0;
        for (Point p : ps) {
            mx += p.x;
            my += p.y;
        }
        return new Point(mx / ps.size(), my / ps.size());
    }

    static char seq[] = new char[NEED10];
    static void readseq_fast(BufferedReader rd, Sat sat) throws IOException {

        // not perfect C-like code for reading satellite sequence
        int s = 1;
        char l = (char)rd.read();
        char c = (char)rd.read();
        while (l == c) {
            c = (char)rd.read();
            s++;
        }
        sat.subshift = s % 10;
        for (int j = 0; j < s; j++) {
            seq[j] = l;
        }
        seq[s] = c;
        rd.read(seq, s + 1, NEED10 - s - 1 - 1);
        rd.skip((SEQLEN10 - NEED10));
        char[] rseq = new char[NEED];
        for (int k = sat.subshift, r = 0; r < NEED; k+=10, r++) {
            rseq[r] = seq[k];
        }
        sat.seq = new String(rseq);
        rd.readLine();
    }

    static void readseq(BufferedReader rd, Sat sat) throws IOException {
        // this is just workaround for some stdin reading problems
        String h = rd.readLine();

        int s = 1;
        int i = 0;
        char l = h.charAt(i);
        i++;
        char c = h.charAt(i);
        i++;
        while (l == c) {
            c = h.charAt(i);
            i++;
            s++;
        }
        sat.subshift = s % 10;

        char[] rseq = new char[NEED];
        for (int k = sat.subshift, r = 0; r < NEED; k+=10, r++) {
            if (h.charAt(k) != '1' && h.charAt(k) != '0') {
                throw new RuntimeException("" + k + " " + (int)h.charAt(k));
            }
            rseq[r] = h.charAt(k);
        }
        sat.seq = new String(rseq);
        log("READING " + sat.seq.substring(11100, 11120));
        //rd.readLine();
    }

    static double sq(double v) {
        return v*v;
    }

    static double trian(Sat s1, Sat s2, Sat s3) {
        double d1 = s1.dist(s2);
        double d2 = s2.dist(s3);
        double d3 = s3.dist(s1);
        double p = (d1 + d2 + d3) / 2;
        return sqrt(p * (p - d1) * (p - d2) * (p - d3));
    }

    static List<Point> circ_int2(Sat s1, Sat s2) {
        return circ_int2(s1.p.x, s1.p.y, s1.dist, s2.p.x, s2.p.y, s2.dist);
    }

    static List<Point> circ_int2(double x1, double y1, double r1, double x2, double y2, double r2) {

        double e = (x2 - x1);
        double f = (y2 - y1);

        double p = sqrt(sq(e) + sq(f));
        double k = (p*p + sq(r1) - sq(r2))/(2*p);

        double dx = (f/p)*sqrt(sq(r1) - sq(k));
        double dy = (e/p)*sqrt(sq(r1) - sq(k));
        double ax = x1 + e*k/p;
        double ay = y1 + f*k/p;

        double rx1 = ax + dx;
        double ry1 = ay - dy;
        Point p1 = new Point(rx1, ry1);

        double rx2 = ax - dx;
        double ry2 = ay + dy;
        Point p2 = new Point(rx2, ry2);

        List<Point> r = new LinkedList<Point>();
        if (p1.check()) r.add(p1);
        if (p2.check()) r.add(p2);
        return r;
    }

}
