//@darkslave


import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.LinkedList;
import java.util.List;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;




class Const {
    public static final double LIGHT_SPEED    = 299_792_458;
    public static final double TRANSFER_SPEED = 10_000_000;
    public static final int    TRANSFER_PADD  = 10;

    public static final double DIST_PER_TAKT  = LIGHT_SPEED / TRANSFER_SPEED;

    public static final double RADIUS_ORBIT_MIN = 10_000_000;
    public static final double RADIUS_ORBIT_MAX = 20_000_000;
    public static final double RADIUS_EARTH     = 6_378_000;

    public static final int    SEARCH_OFFSET_MIN = (int) ((RADIUS_ORBIT_MIN - RADIUS_EARTH) / DIST_PER_TAKT / TRANSFER_PADD) * TRANSFER_PADD;
    public static final int    SEARCH_OFFSET_MAX = (int) ((RADIUS_ORBIT_MAX + RADIUS_EARTH) / DIST_PER_TAKT / TRANSFER_PADD) * TRANSFER_PADD;

    private Const() {}
}



public class GlonAss {
    private static final boolean DEBUG = false;

    public static void main(String[] args) {
        try {
            if (DEBUG) {
                System.setIn(Files.newInputStream(Paths.get("test3.in")));
            }

            long tt = System.nanoTime();

            new GlonAss().start();

            if (DEBUG) {
                System.out.printf("full: %.3f ms%n", (System.nanoTime() - tt) * 1e-6);
            }

        } catch (Exception e) {
            e.printStackTrace(System.out);
        }
    }

    private GlonAss() {}

    private void start() throws IOException, UserException, InterruptedException, ExecutionException {
        try (BufferedReader reader = new BufferedReader(new InputStreamReader(System.in), 1 << 20)) {
            int count = StringParser.toInteger(reader.readLine(), -1);
            if (count < 2 || count > 255)
                throw new UserException("Satellite count is invalid");

            ExecutorService pool = Executors.newFixedThreadPool(count);
            List<Future<Circle>> task = new ArrayList<>(count);
            long hash = HashGenerator.getHash();

            for (int index = 0; index < count; index++) {
                task.add(pool.submit(new Worker(reader, hash, "Satellite " + (index + 1))));
            }

            Circle[] sattelites = new Circle[count];

            for (int index = 0; index < count; index++) {
                Circle satt = task.get(index).get();
                sattelites[index] = satt;
                if (DEBUG) {
                    System.out.println("Sattelite " + (index + 1) + ": " + satt);
                }
            }

            long tt = System.nanoTime();

            List<Point> points = new LinkedList<>();

            // попарно ищем пересечения и добавляем только точки внутри Земли
            for (int index = 0; index < count; index++) {
                for (int other = index + 1; other < count; other++) {
                    for (Point p : Circle.intersect(sattelites[index], sattelites[other])) {
                        if (p.distance() < Const.RADIUS_EARTH) {
                            points.add(p);
                        }
                    }
                }
            }

            if (DEBUG) {
                System.out.println(points);
            }

            if (points.size() > 0) {
                Point result = points.size() > 1 ? findGood(points) : points.get(0);
                System.out.printf("%.3f %.3f%n", result.getX(), result.getY());
            } else {
                System.out.println("no intersection");
            }

            if (DEBUG) {
                System.out.printf("find: %.3f ms%n", (System.nanoTime() - tt) * 1e-6);
            }

            pool.shutdownNow();
        }
    }


    private static Point findGood(List<Point> points) {
        int pointsCount = points.size();

        // общитываем регионы вокруг точек в пределах погрешности измерений
        List<JoinedPoints> joined = new ArrayList<>(pointsCount);

        for (Point first : points) {
            JoinedPoints join = new JoinedPoints(first, Const.DIST_PER_TAKT * Const.TRANSFER_PADD);

            for (Point other : points)
                if (other != first)
                    join.add(other);

            if (join.size() > 0)
                joined.add(join);
        }

        if (joined.size() == 0)
            return points.get(0);

        // сортируем регионы в порядке ухудшения
        Collections.sort(joined, JoinedPoints.COMPARE_BY_DIFF_DESC);

        if (DEBUG) {
            System.out.println(joined);
        }

        // и высчитываем среднюю точку для самого лучшего
        return Point.getAvg(joined.get(0).getPoints());
    }


}



class Worker implements Callable<Circle> {
    private final double coordX;
    private final double coordY;
    private final String data;
    private final String name;
    private final long   hash;

    public Worker(BufferedReader reader, long hash, String name) throws UserException, IOException {
        Double x = StringParser.toDouble(reader.readLine(), null);
        if (x == null)
            throw new UserException(name  + ": Coordinate X is invalid");

        Double y = StringParser.toDouble(reader.readLine(), null);
        if (y == null)
            throw new UserException(name + ": Coordinate Y is invalid");

        this.coordX = x;
        this.coordY = y;

        this.data = reader.readLine();
        this.hash = hash;
        this.name = name;

    }

    @Override
    public Circle call() throws Exception {
        // начальное смещение
        char first = data.charAt(0);
        int offsetInit = 0;
        for (int i = 1, n = data.length(); i < n; i++) {
            if (data.charAt(i) != first) {
                offsetInit = i % Const.TRANSFER_PADD;
                break;
            }
        }

        // грубый поиск первых 64 бит
        long buffer = 0;
        int offset = offsetInit + Const.SEARCH_OFFSET_MIN;
        int finish = Math.min(Const.SEARCH_OFFSET_MAX, data.length() - Const.TRANSFER_PADD);
        int index  = 0;

        while (offset < finish) {
            buffer = (buffer << 1) | (data.charAt(offset) == '1' ? 1 : 0);
            index++;

            if (index >= 64 && buffer == hash)
                break;

            offset += Const.TRANSFER_PADD;
        }

        double radius = 0.0;

        if (offset < finish) {
            radius = (offset - 63 * Const.TRANSFER_PADD) * Const.DIST_PER_TAKT;
        }

        return new Circle(coordX, coordY, radius);
    }
}



class HashGenerator {
    private static final String HASH_PREFIX = "3.1415926535897932384626433832795028841971693993751058209749445923078164062862089986280348253421170679821480865132823066470938446";

    public static long getHash() {
        try {
            MessageDigest origin = MessageDigest.getInstance("MD5");
            origin.update(HASH_PREFIX.getBytes());

            long result = 0;

            for (int i = 0; i < 64; i++)
                result = (result << 1) | (nextHashBit(origin, i) ? 1 : 0);

            return result;

        } catch (NoSuchAlgorithmException | CloneNotSupportedException e) {
            // never occur
            throw new RuntimeException(e);
        }
    }

    private static boolean nextHashBit(MessageDigest origin, int i) throws CloneNotSupportedException {
        MessageDigest temp = (MessageDigest) origin.clone();
        temp.update(Integer.toString(i).getBytes());
        byte[] resp = temp.digest();
        return (resp[0] & 0xF0) > 0x70;
    }

}



class UserException extends Exception {
    private static final long serialVersionUID = 1L;

    public UserException(String message, Throwable cause) {
        super(message, cause);
    }

    public UserException(String message) {
        super(message);
    }

    public UserException(Throwable cause) {
        super(cause);
    }

}



class StringParser {
    public static Integer toInteger(String source, Integer value) {
        try {
            if (isEmpty(source))
                return value;
            return (int) Double.parseDouble(source);
        } catch (NumberFormatException e) {
            return value;
        }
    }

    public static Double toDouble(String source, Double value) {
        try {
            if (isEmpty(source))
                return value;
            return Double.parseDouble(source);
        } catch (NumberFormatException e) {
            return value;
        }
    }

    public static boolean isEmpty(CharSequence source) {
        return source == null || source.length() == 0;
    }

}



class Point {
    protected final double x;
    protected final double y;

    public Point(double x, double y) {
        this.x = x;
        this.y = y;
    }

    public double getX() {
        return x;
    }

    public double getY() {
        return y;
    }

    public double distance() {
        return Math.sqrt(x * x + y * y);
    }

    public double distance(Point other) {
        double dx = other.x - x;
        double dy = other.y - y;
        return Math.sqrt(dx * dx + dy * dy);
    }

    public String toString() {
        return "{" + x + "; " + y + "}";
    }

    public static Point getAvg(Collection<Point> points) {
        if (points.size() == 0)
            throw new IllegalArgumentException();

        double x = 0.0;
        double y = 0.0;

        for (Point item : points) {
            x += item.getX();
            y += item.getY();
        }

        return new Point(x / points.size(), y / points.size());
    }

}



class Circle extends Point {
    protected final double r;

    public Circle(double x, double y, double r) {
        super(x, y);
        this.r = r;
    }

    public double getR() {
        return r;
    }

    public String toString() {
        return "{" + x + "; " + y + "; " + r + "}";
    }

    public static Point[] intersect(Circle A, Circle B) {
        double dx = B.x - A.x;
        double dy = B.y - A.y;
        double dr = Math.sqrt(dx * dx + dy * dy);

        if (dr > A.r + B.r)
            return EMPTY;

        double na = A.r / dr;
        double nb = B.r / dr;
        double j  = (1 + na * na - nb * nb) / 2;
        double s  = Math.sqrt(na * na - j * j);

        double px = A.x + dx * j;
        double py = A.y + dy * j;
        double ix = dy * s;
        double iy = dx * s;

        return new Point[] {
                new Point(px + ix, py - iy),
                new Point(px - ix, py + iy)
        };
    }

    private static final Point[] EMPTY = new Point[0];
}



class JoinedPoints {
    private final List<Point> points;
    private final Point first;
    private final double threshold;
    private double full = 0.0;
    private double avgs = 0.0;
    private int    size = 0;

    public JoinedPoints(Point first, double radius) {
        threshold = radius * radius;

        points = new LinkedList<>();
        points.add(first);

        this.first = first;
    }

    public void add(Point point) {
        double x = first.getX() - point.getX();
        double y = first.getY() - point.getY();

        double diff = x * x + y * y;
        if (diff > threshold)
            return;

        points.add(point);
        size++;

        full+= diff;
        avgs = full / size;
    }

    public List<Point> getPoints() {
        return points;
    }

    public int size() {
        return size;
    }

    public String toString() {
        return first + "; " + size + "; " + avgs;
    }

    public static final Comparator<JoinedPoints> COMPARE_BY_DIFF_DESC = new Comparator<JoinedPoints>() {
        @Override
        public int compare(JoinedPoints A, JoinedPoints B) {
            return Double.compare(A.avgs, B.avgs);
        }
    };

}

