//@eml79
import java.awt.geom.Point2D;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;

public class App {

    static final char[] seq = "111001100011101101".toCharArray();
    static final double KL = 299792458.0 / 10000000.0;
    static final double SZ2 = (6378000.0 + KL / 2) * (6378000.0 + KL / 2) + 1.0;
    static ArrayList<Cs> cs;

    static SpData[] read(BufferedReader reader) throws IOException {
        Integer c = Integer.parseInt(reader.readLine());
        SpData[] d = new SpData[c];
        for (int i = 0; i < c; i++) {
            d[i] = new SpData(Double.parseDouble(reader.readLine()),
                    Double.parseDouble(reader.readLine()), reader.readLine());
        }
        reader.close();
        return d;
    }

    static boolean checkLag(String code, int n) {
        int ci = n * 10;
        for (char c : seq) {
            if (code.charAt(ci) != c) {
                return false;
            }
            ci += 10;
        }
        return true;
    }

    static int findLag(String code) {
        for (int k = 12000; k < 88000; k++) {
            if (checkLag(code, k)) {
                return (k - 1) * 10 + code.indexOf(code.charAt(0) == '0' ? '1' : '0', 1) % 10;
            }
        }
        return -1;
    }

    static void solve(double x1, double y1, double r1, double x2, double y2, double r2) {

        double x12 = x1 * x1,
                y12 = y1 * y1,
                r12 = r1 * r1,
                yb = y1 - y2,
                ya = x2 - x1,
                yc = x12 + y12 - r12 - x2 * x2 - y2 * y2 + r2 * r2,
                ds = Math.sqrt(ya * ya + yb * yb);
        if (ds < Math.abs(r1 - r2)) {
            return;
        }
        if (ds >= r1 + r2) {
            double k = r1 / (r1 + r2);
            cs.add(new Cs(new Point2D.Double(x1 + (x2 - x1) * k, y2 + (y2 - y1) * k), null));
            return;
        }
        ya = ya / yb;
        yc = yc / 2 / yb;
        double a = 1 + ya * ya,
                b = 2 * (ya * (yc - y1) - x1),
                c = x12 + yc * (yc - 2 * y1) + y12 - r12,
                d = b * b - 4 * a * c;
        if (d == 0) {
            double px = -b / (2 * a);
            cs.add(new Cs(new Point2D.Double(px, ya * px + yc), null));
        } else if (d > 0) {
            d = Math.sqrt(d);
            double px1 = (-b + d) / (2 * a),
                    px2 = (-b - d) / (2 * a);
            cs.add(new Cs(new Point2D.Double(px1, ya * px1 + yc), new Point2D.Double(px2, ya * px2 + yc)));
        }
    }

    static double getMD(Point2D.Double p1, Point2D.Double p2) {
        double dx = p1.x - p2.x,
                dy = p1.y - p2.y;
        return dx * dx + dy * dy;
    }

    static void run(BufferedReader reader) throws Exception {
        //ввод данных, расчет расстояний
        SpData[] data = read(reader);
        final int dl = data.length;
        for (int i = 0; i < dl; i++) {
            data[i].d = KL * (findLag(data[i].data) - 0.5);
        }
        //Точки пересечений окружностей
        cs = new ArrayList();
        if (dl % 2 == 0) {
            for (int i = 1; i < dl; i += 2) {
                solve(data[i - 1].x, data[i - 1].y, data[i - 1].d,
                        data[i].x, data[i].y, data[i].d);
            }
        } else {
            solve(data[0].x, data[0].y, data[0].d,
                    data[dl - 1].x, data[dl - 1].y, data[dl - 1].d);
            for (int i = 1; i < dl; i++) {
                solve(data[i - 1].x, data[i - 1].y, data[i - 1].d,
                        data[i].x, data[i].y, data[i].d);
            }
        }
        //Отсев точек пересечения
        for (int i = cs.size() - 1; i >= 0; i--) {
            Cs s = cs.get(i);
            if (s.p2 != null) {
                double d = s.p2.x * s.p2.x + s.p2.y * s.p2.y;
                if (d > SZ2) {
                    s.p2 = null;
                }
            }
            double d = s.p1.x * s.p1.x + s.p1.y * s.p1.y;
            if (d > SZ2) {
                if (s.p2 == null) {
                    cs.remove(i);
                }
                s.p1 = s.p2;
                s.p2 = null;
            }
        }
        for (int i = 0; i < cs.size(); i++) {
            Cs s = cs.get(i);
            if ((s.p1 != null) && (s.p2 != null)) {
                int c1 = 0, c2 = 0;
                for (int j = 0; j < cs.size(); j++) {
                    if (i != j) {
                        Cs t = cs.get(j);
                        double d1 = getMD(t.p1, s.p1), d2 = getMD(t.p1, s.p2);
                        if (t.p2 != null) {
                            d1 = Math.min(d1, getMD(t.p2, s.p1));
                            d2 = Math.min(d2, getMD(t.p2, s.p2));
                        }
                        if (d1 < d2) {
                            c1++;
                        } else {
                            c2++;
                        }
                    }
                }
                if (c1 < c2) {
                    s.p1 = s.p2;
                }
            }
        }
        //Усредняем
        double x = 0, y = 0;
        for (Cs s : cs) {
            x += s.p1.x;
            y += s.p1.y;
        }
        x = x / cs.size();
        y = y / cs.size();
        System.out.println(x + " " + y);
    }

    public static void main(String[] args) throws Exception {
        run(new BufferedReader(new InputStreamReader(System.in)));
    }

    static class SpData {

        final double x;
        final double y;
        final String data;
        double d;

        public SpData(double x, double y, String data) {
            this.x = x;
            this.y = y;
            this.data = data;
        }
    }

    static class Cs {

        Point2D.Double p1, p2;

        public Cs(Point2D.Double p1, Point2D.Double p2) {
            this.p1 = p1;
            this.p2 = p2;
        }
    }
}
