//@indy256

import java.io.*;
import java.security.MessageDigest;
import java.util.Arrays;

public class Glonass {

	public static void main(String[] args) throws Exception {

		MessageDigest md = MessageDigest.getInstance("MD5");
		byte[] ref = new byte[10_000_000];
		Arrays.fill(ref, (byte) -1);
		for (int pos = 0; pos < 1000_000; pos++) {
			md.reset();
			String s = "3.1415926535897932384626433832795028841971693993751058209749445923078164062862089986280348253421170679821480865132823066470938446" + pos;
			byte[] digest = md.digest(s.getBytes());
			byte digit = (digest[0] >>> 4) > 7 ? (byte) 1 : (byte) 0;
			for (int i = 0; i < 10; i++)
				ref[pos * 10 + i] = digit;
		}

		int refShift = minCyclicShift(ref);

		BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
		int n = Integer.parseInt(br.readLine());
		double[] x = new double[n];
		double[] y = new double[n];
		double[] d = new double[n];
		int[] shifts = new int[n];

		for (int i = 0; i < n; i++) {
			x[i] = Double.parseDouble(br.readLine());
			y[i] = Double.parseDouble(br.readLine());
			String s = br.readLine();
			char[] a = s.toCharArray();
			byte[] b = new byte[a.length];
			for (int j = 0; j < b.length; j++)
				b[j] = a[j] == '0' ? (byte) 0 : (byte) 1;
			shifts[i] = minCyclicShift(b);
			int delta = (shifts[i] - refShift + ref.length) % ref.length;
			d[i] = delta / 10000000.0 * 299792458.0;
		}

		double curX = 0;
		double curY = 0;
		double curF = f(x, y, d, curX, curY);
		for (double step = 1e6; step > 1e-9; ) {
			double bestF = curF;
			double bestX = curX;
			double bestY = curY;
			boolean find = false;
			for (int i = 0; i < 6; i++) {
				double a = 2 * Math.PI * i / 6;
				double nextX = curX + step * Math.cos(a);
				double nextY = curY + step * Math.sin(a);
				if (fastHypot(nextX, nextY) > 6378_000)
					continue;
				double nextF = f(x, y, d, nextX, nextY);
				if (bestF > nextF) {
					bestF = nextF;
					bestX = nextX;
					bestY = nextY;
					find = true;
				}
			}
			if (!find) {
				step /= 2;
			} else {
				curX = bestX;
				curY = bestY;
				curF = bestF;
			}
		}

		System.out.println(curX + " " + curY);
	}

	static double f(double[] x, double[] y, double[] d, double curX, double curY) {
		double res = 0;
		for (int i = 0; i < x.length; i++) {
			double diff = d[i] - fastHypot(x[i] - curX, y[i] - curY);
			res += Math.abs(diff);
		}
		return res;
	}

	static double fastHypot(double x, double y) {
		return Math.sqrt(x * x + y * y);
	}

	static int minCyclicShift(byte[] a) {
		byte[] s = new byte[a.length * 2];
		System.arraycopy(a, 0, s, 0, a.length);
		System.arraycopy(a, 0, s, a.length, a.length);
		int n = s.length;
		int i = 0, res = 0;
		while (i < n / 2) {
			res = i;
			int j = i + 1;
			int k = i;
			while (j < n && s[k] <= s[j]) {
				if (s[k] < s[j])
					k = i;
				else
					++k;
				++j;
			}
			while (i <= k)
				i += j - k;
		}
		return res;
	}
}
