//@ingvord

//package by.wayray.glonass2063;

import java.io.BufferedReader;
import java.io.IOException;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.text.DecimalFormat;
import java.text.NumberFormat;
import java.util.*;
import java.util.concurrent.*;

/**
 * @author Ingvord
 * @since 11.05.14@11:53
 */
public class Main {
    public static final long SPEED_OF_LIGHT = 299792458L;
    public static final MessageDigest MD5 = getMd5();
    private static final int SEARCH_PRECISION = 10;
    public static final Point[] NO_ANSWER = new Point[]{new Point(Double.NaN, Double.NaN)};
    public static final int VALID_RADIUS = 6378000;

    static MessageDigest getMd5() {
        try {
            return MessageDigest.getInstance("MD5");
        } catch (NoSuchAlgorithmException e) {
            throw new RuntimeException(e);
        }
    }

    public static final double DELTA = 100D;
    public static final int MESSAGE_LENGTH = 1000000;
    public static final int INPUT_LENGTH = MESSAGE_LENGTH * 10;
    public static final EncodedMessage MESSAGE = generateMessage();

    public static EncodedMessage generateMessage() {
        StringBuilder result = new StringBuilder();
        for (int pos = 0; pos < MESSAGE_LENGTH; ++pos) {
            String input = "3.1415926535897932384626433832795028841971693993751058209749445923078164062862089986280348253421170679821480865132823066470938446" + Integer.toString(pos);
            MD5.update(input.getBytes());
            byte[] data = MD5.digest();
            if ((0xFF & data[0]) > 0x7F) result.append('1');
            else result.append('0');
        }
        return encode(result.toString());
    }

    public static final int CPUS = Runtime.getRuntime().availableProcessors();
    public static final ExecutorService EXEC = Executors.newFixedThreadPool(CPUS);

    public static void main(String... args) {
        long start = System.nanoTime();
        try {

            for (MutableInteger counter : MESSAGE.ndxs)
                counter.value *= 10;

            final Input[] inputData = getInput(Paths.get(args[0]));

            int numbersOfSputniks = inputData.length;

            final Sputnik[] sputniks = new Sputnik[numbersOfSputniks];

            final CountDownLatch findOffsets = new CountDownLatch(sputniks.length);

            final double[] distances = new double[sputniks.length];
            for (int i = 0, sputniksLength = sputniks.length; i < sputniksLength; i++) {
                final int ndx = i;

                Runnable runnable = new Runnable() {
                    public void run() {
                        System.out.println("Start process sputnik #" + ndx);
                        double x = Double.parseDouble(inputData[ndx].x);
                        double y = Double.parseDouble(inputData[ndx].y);
                        EncodedMessage input = encode(inputData[ndx].data);
                        Sputnik sputnik = sputniks[ndx] = new Sputnik((byte)ndx, x, y, input);
                        long offset = calculateOffset(sputnik.input, MESSAGE);
                        double t = (double) offset / INPUT_LENGTH;
                        double distance = t * SPEED_OF_LIGHT;
                        distances[ndx] = distance;
                        findOffsets.countDown();
                    }
                };
                EXEC.submit(runnable);
            }

            findOffsets.await();
            final Set<Point> intersections = new TreeSet<>(new Comparator<Point>() {

                @Override
                public int compare(Point o1, Point o2) {
                    double d = Math.sqrt(Math.pow(o1.x - o2.x, 2) + Math.pow(o1.y-o2.y,2));

                    if(Double.compare(d,DELTA) < 1) return 0;
                    else
                        return 1;
                }
            });
            for (int i = 0, sputniksLength = sputniks.length; i < sputniksLength - 1; i++) {
                intersections.addAll(Arrays.asList(calculateIntersection(sputniks[i], distances[i], sputniks[++i], distances[i])));
            }

            for (Iterator<Point> iterator = intersections.iterator(); iterator.hasNext(); ) {
                Point point = iterator.next();
                if (Math.sqrt(point.x * point.x + point.y * point.y) > VALID_RADIUS) iterator.remove();
            }

            System.out.println(intersections);

            EXEC.shutdown();
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        } finally {
            System.out.print("Total time (ms): ");
            System.out.println(TimeUnit.MILLISECONDS.convert(System.nanoTime() - start, TimeUnit.NANOSECONDS));
        }

    }

    private static Point[] calculateIntersection(Sputnik s1, double r1, Sputnik s2, double r2) {
        double s2_minus_s1_x = s2.point.x - s1.point.x;
        double s2_minus_s1_y = s2.point.y - s1.point.y;

        double d = Math.sqrt(Math.pow(s2_minus_s1_x, 2) + Math.pow(s2_minus_s1_y, 2));
        if ((d < Math.abs(r1 - r2)) || (d > r1 + r2)) return NO_ANSWER;

        double b = (r2 * r2 - r1 * r1 + d * d) / (2 * d);
        double a = d - b;
        double h = Math.sqrt(r1 * r1 - a * a);

        double x0 = s1.point.x + a * s2_minus_s1_x / d;
        double y0 = s1.point.y + a * s2_minus_s1_y / d;

        double x_res_1 = x0 + h * s2_minus_s1_y / d;
        double y_res_1 = y0 - h * s2_minus_s1_x / d;

        double x_res_2 = x0 - h * s2_minus_s1_y / d;
        double y_res_2 = y0 + h * s2_minus_s1_x / d;

        return new Point[]{new Point(x_res_1, y_res_1), new Point(x_res_2, y_res_2)};
    }

    public static Input[] getInput(Path pathToInput) {
        Input[] result;
        try (BufferedReader rdr = Files.newBufferedReader(pathToInput, Charset.forName("UTF-8"))) {
            int n = Integer.parseInt(rdr.readLine());
            result = new Input[n];
            for(int i = 0; i <n; ++i){
                result[i] = new Input(rdr.readLine(),rdr.readLine(),rdr.readLine());
            }
            return result;
        } catch (IOException ioe) {
            throw new RuntimeException(ioe);
        }
    }

    public static class Input {
        private final String x;
        private final String y;
        private final String data;

        public Input(String x, String y, String data) {
            this.x = x;
            this.y = y;
            this.data = data;
        }
    }

    public static class Point {
        private final double x;
        private final double y;

        public Point(double x, double y) {
            this.x = x;
            this.y = y;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Point point = (Point) o;

            if (Double.compare(point.x, x) != 0) return false;
            if (Double.compare(point.y, y) != 0) return false;

            return true;
        }

        @Override
        public int hashCode() {
            int result;
            long temp;
            temp = Double.doubleToLongBits(x);
            result = (int) (temp ^ (temp >>> 32));
            temp = Double.doubleToLongBits(y);
            result = 31 * result + (int) (temp ^ (temp >>> 32));
            return result;
        }

        @Override
        public String toString() {
            return "" + x + " " + y;
        }
    }

    public static final NumberFormat NUMBER_FORMAT = new DecimalFormat("0.#####E0");

    public static void printPoint(Point p){
        System.out.print(NUMBER_FORMAT.format(p.x));
        System.out.print("\\s");
        System.out.println(NUMBER_FORMAT.format(p.y));
    }

    public static class Sputnik {
        private final byte id;
        private final Point point;
        private final EncodedMessage input;

        public Sputnik(byte id, double x, double y, EncodedMessage input) {
            this.id = id;
            this.point = new Point(x, y);
            this.input = input;
        }
    }

    public static EncodedMessage encode(String message) {
        StringBuilder encoded = new StringBuilder();

        ArrayList<MutableInteger> ndxs = new ArrayList<>();

        char lastBit = 1;
        char[] charArray = message.toCharArray();
        for (int i = 0, ndx = -1, charArrayLength = charArray.length; i < charArrayLength; i++) {
            char bit = charArray[i];
            if (!(bit == 48 || bit == 49)) throw new IllegalArgumentException("Bad message");

            if (lastBit != bit) {
                encoded.append(bit);
                MutableInteger counter = new MutableInteger();
                counter.value = 1;
                ndxs.add(++ndx, counter);
            } else {
                ndxs.get(ndx).value++;
            }
            lastBit = bit;
        }
        ndxs.trimToSize();
        return new EncodedMessage(encoded.toString(), ndxs);
    }

    public static long calculateOffset(EncodedMessage input, EncodedMessage message) {
        int ndx = Collections.indexOfSubList(input.ndxs, message.ndxs.subList(0, SEARCH_PRECISION));
        if (ndx < 0) throw new IllegalArgumentException("Can not find message in the input sequence");
        if (input.message.charAt(ndx) != message.message.charAt(0))
            throw new IllegalStateException("First bits do not match");//TODO re search with greater precision

        long result = 0;
        for (int i = 0; i < ndx; ++i) {
            result += input.ndxs.get(i).value;
        }
        return result;

    }

    public static class MutableInteger implements Comparable<MutableInteger> {
        public int value;

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MutableInteger that = (MutableInteger) o;

            if (value != that.value) return false;

            return true;
        }

        @Override
        public int hashCode() {
            return value;
        }

        @Override
        public int compareTo(MutableInteger o) {
            return Integer.compare(value, o.value);
        }

        @Override
        public String toString() {
            return "" + value;
        }
    }

    public static class EncodedMessage {
        //TODO replace with first bit only
        public final String message;
        public final ArrayList<MutableInteger> ndxs;

        public EncodedMessage(String encoded, ArrayList<MutableInteger> ndxs) {
            this.message = encoded;
            this.ndxs = ndxs;
        }
    }
}
