//@ipulsar
import java.awt.Point;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Scanner;


public class PositionFinder {
	private static final int MIN_190_ONES_OFFSET = 6375480;
	private static final int SEQUENCE_LENGTH = 10_000_000;
	private static final double LIGHT_SPEED = 299792458d;
	// точность определения квадрата расстояния для расстояния 100 м
	private static final double EPS_DIST_SQ = 100 * 100;
	private static final double MAX_RECEIVER_DISTANCE = 6_378_000;
	
	private static int numSatellites;
	private static double[] x;
	private static double[] y;
	private static double[] r;

	public static void main(String[] args) throws Exception {
		readInputData();

		Point position = findReceiverPosition();
		
		System.out.println(String.format(Locale.US, "%E %E", position.getX(), position.getY()));
	}

	private static void readInputData() throws IOException, Exception {
		byte[] data = new byte[SEQUENCE_LENGTH];
		
		System.in.read(data, 0, 50);
		String s = new String(data, 0, 50);
		Scanner scanner = new Scanner(s);
		scanner.useLocale(Locale.US);
		
		numSatellites = scanner.nextInt();
		x = new double[numSatellites];
		y = new double[numSatellites];
		r = new double[numSatellites];
		
		for (int i = 0; i < numSatellites; i++) {
			x[i] = scanner.nextDouble();
			y[i] = scanner.nextDouble();
			int sequencePrefix = scanner.next().length();
			scanner.close();
			System.in.read(data, 0, SEQUENCE_LENGTH - sequencePrefix);
			//System.out.write(data, 0, 1000);System.out.println();
			r[i] = findDistanceToSatellite(data, sequencePrefix);

			if (i != numSatellites - 1) {
				System.in.read(data, 0, 50);
				s = new String(data, 0, 50);
				scanner = new Scanner(s);
				scanner.useLocale(Locale.US);
			}
		}
	}
	
	private static double findDistanceToSatellite(byte[] data, int sequencePrefix) throws Exception {
		int offset = MIN_190_ONES_OFFSET - sequencePrefix;
		int counter = 0;
		boolean isOne = false;
		
		for (int i = offset; i < SEQUENCE_LENGTH - sequencePrefix; i++) {
			if (data[i] == 0x31) {
				if (!isOne) {
					isOne = true;
					offset = i;
					counter = 0;
				} 
				counter++;
				if (counter == 190)
					break;
			} else if (isOne)
				isOne = false;
		}

		if (counter != 190)
			throw new Exception("190 ones not found");
		else {
			// -1, потому что сигнал не может дойти мгновенно даже при 
			// размещении спутника и приемника в одной точке
			int sequenceStartOffset = offset - MIN_190_ONES_OFFSET - 1 + sequencePrefix;
			double timeOffset = sequenceStartOffset / (double) SEQUENCE_LENGTH;
			double distance = timeOffset * LIGHT_SPEED;
			return distance;
		}
	}

	private static Point findReceiverPosition() {
		Point result = new Point();
		
		// если дано два спутника, центры которых находятся в одной точке,
		// вернуть точку окружности, ближайшую к началу координат 
		if (numSatellites == 2 && x[0] == x[1] && y[0] == y[1]) {
			double k = 1 - r[0] / Math.sqrt(x[0] * x[0] + y[0] * y[0]);
			result.setLocation(k * x[0], k * y[0]);
			return result;
		}
		
		List<Point> intersections = new ArrayList<Point>((numSatellites -1) * 2);
		Point[] candidates = new Point[2];
		boolean candidateSelected = false;

		for (int i = 0; i < numSatellites; i++) {
			for (int j = i + 1; j < numSatellites; j++) {
				// две окружности с центрами в одной точке игнорируются
				if (x[j] == x[i] && y[j] == y[i])
					continue;

				double dx = (x[j] - x[i]);
				double dy = (y[j] - y[i]);
				double d = Math.sqrt(dx * dx + dy * dy);

				// окружности не пересекаются
				if ((r[j] + r[i]) < d || Math.abs(r[j] - r[i]) > d)
					continue;

				double b = (r[j] * r[j] - r[i] * r[i] + d * d) / (2 * d);
				double a = d - b;
				double h = Math.sqrt(r[i] * r[i] - a * a);
				double p0x = x[i] + a / d * dx;
				double p0y = y[i] + a / d * dy;
				Point p3 = new Point();
				p3.setLocation(p0x + dy / d * h, p0y - dx / d * h);
				Point p4 = null;
				if (h != 0.0) {
					p4 = new Point();
					p4.setLocation(p0x - dy / d * h, p0y + dx / d * h);
				}

				if (!candidateSelected) {
					if (candidates[0] == null) {
						// первая пара спутников с вычисленным пересечением дает до двух точек-кандидатов
						int idx = 0;
						if (p3.distance(0.0, 0.0) <= MAX_RECEIVER_DISTANCE)
							candidates[idx++] = p3;
						if (p4 != null && p4.distance(0.0, 0.0) <= MAX_RECEIVER_DISTANCE)
							candidates[idx] = p4;
					} else {
						// вторая пара спутников с вычисленным пересечением выбирает из двух кандидатов
						// точку, в окрестностях которой находится приемник
						double[] distances = new double[4];
						distances[0] = candidates[0].distanceSq(p3);
						distances[1] = candidates[1] != null ? candidates[1].distanceSq(p3) : Double.MAX_VALUE;
						distances[2] = p4 != null ? candidates[0].distanceSq(p4) : Double.MAX_VALUE;
						distances[3] = p4 != null && candidates[1] != null ? candidates[1].distanceSq(p4) : Double.MAX_VALUE;
						int minIdx = distances[0] < distances[1] ? 0 : 1;
						if (p4 != null) {
							int minIdx2 = distances[2] < distances[3] ? 2 : 3;
							minIdx = distances[minIdx] < distances[minIdx2] ? minIdx
									: minIdx2;
						}
						if (distances[minIdx] < EPS_DIST_SQ) {
							candidateSelected = true;
							if (minIdx % 2 == 1)
								candidates[0] = candidates[1];
							intersections.add(candidates[0]);
							intersections.add(minIdx < 2 ? p3 : p4);
						}
					}
				} else {
					if (candidates[0].distanceSq(p3) < EPS_DIST_SQ)
						intersections.add(p3);
					if (p4 != null
							&& candidates[0].distanceSq(p4) < EPS_DIST_SQ)
						intersections.add(p4);
				}
			}
		}
		
		if (!candidateSelected)
			intersections.add(candidates[0]);
		
		// усреднение координат
		double sumX = 0.0, sumY = 0.0;
		
		for (Point p : intersections) {
			sumX += p.getX();
			sumY += p.getY();
		}
		
		result.setLocation(sumX / intersections.size(), sumY / intersections.size());
		return result;
	}

}
