//@nickus2010


import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/**
 * Майское хабрасоревнование: делаем свой ГЛОНАССS
 * http://habrahabr.ru/company/wayray/blog/222279/
 *
 * @author iusiumbeli_ni (nickus)
 */
public class WayRay2014 {
    private static ExecutorService executorService;
    private static byte[] seq;
    private static int N;


    public static void main(String[] args) throws IOException {
        PrintWriter printWriter = new PrintWriter(System.out);
        init();
        List<Satellite> satellites = getSatellites(System.in);
        firstOutStrategy(printWriter, satellites);
        shutdown();
    }


    private static void firstOutStrategy(PrintWriter printWriter, List<Satellite> satellites) {
        List<double[]> dists = new ArrayList<>();
        double speed = 299792458 / 1000000.0;
        int size = satellites.size();
        for (int i = 0; i < size; i++) {
            for (int j = i + 1; j < size; j++) {
                Satellite satellite1 = satellites.get(i);
                Satellite satellite2 = satellites.get(j);
                double R1 = satellite1.getOffset() * speed;
                double R2 = satellite2.getOffset() * speed;
                dists.add(circlesCrossing(satellite1.x, satellite1.y, R1, satellite2.x, satellite2.y, R2));
            }

        }

        List<double[]> cluster = clustering(dists);
        int count = cluster.size();
        double[][] fisherCalc = fisherCalc(cluster);

        double xSum = 0;
        double ySum = 0;
        int xCount = 0, yCount = 0;
        for (int i = 0; i < cluster.size(); i++) {
            double[] point = cluster.get(i);
            if (fisherCalc[i][0] <= count / 2 * 0.6) {
                xSum += point[0];
                xCount++;
            }
            if (fisherCalc[i][1] <= count / 2 * 0.6) {
                ySum += point[1];
                yCount++;
            }
        }
        printWriter.print(xSum / xCount);
        printWriter.print(" ");
        printWriter.println(ySum / yCount);
        printWriter.flush();
    }

    private static List<double[]> clustering(List<double[]> dists) {
        List<double[]> minDists1 = new ArrayList<>();
        double sum1 = 0;
        double startX1 = dists.get(0)[0];
        double startY1 = dists.get(0)[1];
        minDists1.add(new double[]{startX1, startY1});
        for (int i = 1; i < dists.size(); i++) {
            double[] doubles = dists.get(i);
            double distance1 = distance(startX1, startY1, doubles[0], doubles[1]);
            double distance2 = distance(startX1, startY1, doubles[2], doubles[3]);

            if (distance1 < distance2) {
                minDists1.add(new double[]{doubles[0], doubles[1]});
                sum1 += distance1;
            } else {
                minDists1.add(new double[]{doubles[2], doubles[3]});
                sum1 += distance2;
            }
        }

        List<double[]> minDists2 = new ArrayList<>();
        double sum2 = 0;
        double startX2 = dists.get(0)[2];
        double startY2 = dists.get(0)[3];
        minDists2.add(new double[]{startX2, startY2});
        for (int i = 1; i < dists.size(); i++) {
            double[] doubles = dists.get(i);
            double distance1 = distance(startX2, startY2, doubles[0], doubles[1]);
            double distance2 = distance(startX2, startY2, doubles[2], doubles[3]);

            if (distance1 < distance2) {
                minDists2.add(new double[]{doubles[0], doubles[1]});
                sum2 += distance1;
            } else {
                minDists2.add(new double[]{doubles[2], doubles[3]});
                sum2 += distance2;
            }
        }


        return sum1 <= sum2 ? minDists1 : minDists2;
    }

    private static double distance(double x1, double y1, double x2, double y2) {
        return Math.sqrt(Math.pow(x1 - x2, 2) + Math.pow(y1 - y2, 2));
    }

    private static List<Satellite> getSatellites(InputStream stream) throws IOException {
        List<Satellite> satellites = new ArrayList<>();
        int n = Integer.parseInt(readLine(stream));
        n = Math.min(n, 100);
        for (int i = 0; i < n; i++) {
            double x = Double.parseDouble(readLine(stream));
            double y = Double.parseDouble(readLine(stream));
            byte[] bytes = readBytes(stream, N * 10);

            double offset = findOffset(bytes);

            Satellite satellite = new Satellite(x, y, offset);
            satellites.add(satellite);
        }
        return satellites;
    }

    private static byte[] readBytes(InputStream stream, int n) {
        byte[] res = new byte[n];
        try {
            int b = stream.read();
            while (b == 0xA || b == 0xD) b = stream.read();
            res[0] = (byte) b;
            stream.read(res, 1, n - 1);
        } catch (IOException e) {
            return res;
        }
        return res;
    }

    private static String readLine(InputStream stream) {
        String s = "";
        try {
            int b = stream.read();
            while (b == 0xA || b == 0xD) b = stream.read();
            ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
            while (b != 0xA && b != 0xD) {
                outputStream.write(b);
                b = stream.read();
            }
            s = new String(outputStream.toByteArray());
        } catch (IOException e) {
            return s;
        }
        return s;
    }

    public static double findOffset(byte[] bytes) throws IOException {
        int dec = 0;
        int length = bytes.length;
        for (int i = 1; i < length; i++) {
            dec++;
            if (bytes[i] != bytes[i - 1]) break;
        }
        dec = dec % 10;

        //normalize
        byte[] bytesNew = new byte[length / 10];
        int j = 0;
        for (int i = 0; i < length; i += 10) {
            bytesNew[j++] = (byte) (bytes[i] - '0');
        }
        bytes = bytesNew;

        byte[] newBytes = new byte[bytes.length * 2];
        System.arraycopy(bytes, 0, newBytes, 0, bytes.length);
        System.arraycopy(bytes, 0, newBytes, bytes.length, bytes.length);

        int entry = getFirstEntry2(newBytes, seq);

        if (dec > 0) entry--;
        return (entry - 637547) + dec / 10.0;
    }

    public static int getFirstEntry2(byte[] source, byte[] template) {
        int sourceLen = source.length;
        int templateLen = template.length;
        if (templateLen > sourceLen) {
            return -1;
        }

        int nullId = 19;
        int oneId = 1;
//        int x = 0;
//        for (int i = templateLen - 2; i >= 0 && (nullId < 0 || oneId < 0); i--) {
//            x++;
//            if (template[i] == 0 && nullId < 0) {
//                nullId = x;
//            } else if (template[i] == 1 && oneId < 0) {
//                oneId = x;
//            }
//        }
//
//        nullId = nullId < 0 ? templateLen : nullId;
//        oneId = oneId < 0 ? templateLen : oneId;

        int i = templateLen - 1;
        int j = i;
        int k = i;
        while (j >= 0 && i <= sourceLen - 1) {
            j = templateLen - 1;
            k = i;
            while (j >= 0 && source[k] == template[j]) {
                k--;
                j--;
            }

            i += source[i] == 0 ? nullId : oneId;
        }
        if (k >= sourceLen - templateLen) {
            return -1;
        } else {
            return k + 1;
        }
    }

    /**
     * Пересечение двух окружностей
     *
     * @return
     */
    public static double[] circlesCrossing(double x1, double y1, double R1, double x2, double y2, double R2) {
        double dist = Math.sqrt(Math.pow(x1 - x2, 2) + Math.pow(y1 - y2, 2));
        if (dist > R1 + R2) {
            throw new IllegalArgumentException();
        }

        if (x2 == 0 && y2 == 0) {
            x2 = y2 = 0.0000000001;
        }

        x2 -= x1;
        y2 -= y1;
        double C = (R1 * R1 - R2 * R2 + x2 * x2 + y2 * y2) / 2;
        double aD = x2 * x2 + y2 * y2;
        double bD = -2 * C * x2;
        double cD = -(y2 * y2) * R1 * R1 + C * C;

        double D = bD * bD - 4 * aD * cD;
        double XR1 = (-bD + Math.sqrt(D)) / (2 * aD);
        double XR2 = (-bD - Math.sqrt(D)) / (2 * aD);

        double YR1 = (C - x2 * XR1) / y2;
        double YR2 = (C - x2 * XR2) / y2;
        XR1 += x1;
        XR2 += x1;
        YR1 += y1;
        YR2 += y1;
        return new double[]{XR1, YR1, XR2, YR2};
    }


    public static void init() {
        int processorsCount = Runtime.getRuntime().availableProcessors();
        executorService = Executors.newFixedThreadPool(processorsCount);
        N = 1000000;
        seq = new byte[]{0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
    }

    private static void shutdown() {
        executorService.shutdown();
    }


    public static class Satellite {
        private double x, y;
        private double offset;

        public Satellite(double x, double y, double offset) {
            this.x = x;
            this.y = y;
            this.offset = offset;
        }

        public double getX() {
            return x;
        }

        public double getY() {
            return y;
        }

        public double getOffset() {
            return offset;
        }
    }

    public interface Worker extends Runnable {
        public boolean isCompleted();
    }

    public static abstract class AbstractWorker implements Worker {
        private volatile boolean completed = false;

        @Override
        public boolean isCompleted() {
            return completed;
        }

        public void setCompleted(boolean completed) {
            this.completed = completed;
        }

        public void notifyAllSync() {
            synchronized (this) {
                notifyAll();
            }
        }
    }


    public static double[][] fisherCalc(List<double[]> data) {
        int count = data.size();
        double[][] res = new double[count][2];
        if (count < 4) return res;

        double sum1 = 0;
        double sum2 = 0;
        for (double[] aData : data) {
            sum1 += aData[0];
            sum2 += aData[1];
        }

        double avg1 = sum1 / count;
        double avg2 = sum2 / count;

        double dSum1 = 0;
        double dSum2 = 0;

        double[][] deviation = new double[count][2];
        for (int i = 0; i < count; i++) {
            deviation[i][0] = Math.abs(avg1 - data.get(i)[0]);
            deviation[i][1] = Math.abs(avg2 - data.get(i)[1]);

            dSum1 += deviation[i][0];
            dSum2 += deviation[i][1];
        }

        double dAvg1 = dSum1 / count;
        double dAvg2 = dSum2 / count;

        double student = student(count);
        double dov1 = dAvg1 * student / Math.sqrt(count);
        double dov2 = dAvg2 * student / Math.sqrt(count);

        double min1 = avg1 - dov1;
        double min2 = avg2 - dov2;

        for (int i = 0; i < count; i++) {
            res[i][0] = Math.abs((data.get(i)[0] - min1) / (2 * dov1));
            res[i][1] = Math.abs((data.get(i)[1] - min2) / (2 * dov2));
        }

        return res;
    }


    private static double[] F = new double[]{0, 0, 12.71, 4.30, 3.18, 2.78, 2.57, 2.45, 2.37,
            2.31, 2.26, 2.23, 2.20, 2.18, 2.16, 2.15, 2.13, 2.12, 2.11, 2.10, 2.93, 2.064};

    public static double student(int n) {
        if (n > 120) {
            return 1.960;
        } else if (n > 100) {
            return 1.980;
        } else if (n > 90) {
            return 1.984;
        } else if (n > 80) {
            return 1.987;
        } else if (n > 70) {
            return 1.991;
        } else if (n > 60) {
            return 1.996;
        } else if (n > 50) {
            return 2.001;
        } else if (n > 45) {
            return 2.009;
        } else if (n > 40) {
            return 2.016;
        } else if (n > 35) {
            return 2.022;
        } else if (n > 30) {
            return 2.032;
        } else if (n > 25) {
            return 2.045;
        } else if (n > 20) {
            return 2.064;
        } else {
            return F[n];
        }
    }


}
