//@papageno

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

public class Glonass {

    public static void main(String[] args) throws Exception {
        List<Satellite> satellites = readData(System.in);
        Point pos = getPos(satellites);
        System.out.printf("%e %e\n", pos.x, pos.y);
    }

    public static Point getPos(List<Satellite> satellites) {
        ArrayList<Point> points = new ArrayList<Point>();
        int n = satellites.size();
        for (int i = 0; i < n; i++) {
            for (int j = i + 1; j < n; j++) {
                Collections.addAll(points, triangulate(satellites.get(i), satellites.get(j)));
            }
        }
        n = points.size();
        if (n == 1) return points.get(0);
        if (n == 0) return new Point();

        Point m = median(points);

        double xSum = 0, ySum = 0;
        n = 0;
        for (Point c : points) {
            if ((c.x - m.x) * (c.x - m.x) + (c.y - m.y) * (c.y - m.y) < 1e6) {
                xSum += c.x;
                ySum += c.y;
                n++;
            }
        }
        return n > 0 ? new Point(xSum / n, ySum / n) : m;
    }

    public static Point median(ArrayList<Point> points) {
        int j = 0;
        int p = points.size();
        double[] xa = new double[p];
        double[] ya = new double[p];
        for (Point point : points) {
            xa[j] = point.x;
            ya[j] = point.y;
            j++;
        }
        Arrays.sort(xa);
        Arrays.sort(ya);
        double xm = xa[p / 2];
        double ym = ya[p / 2];
        return new Point(xm, ym);
    }

    private static List<Satellite> readData(InputStream in) throws IOException {
        long timeLimit = System.currentTimeMillis() + 2000;
        BufferedInputStream r = in instanceof BufferedInputStream ? (BufferedInputStream) in : new BufferedInputStream(in);
        List<Satellite> satellites;
        try {
            int num = Integer.valueOf(readLine(r));
            satellites = new ArrayList<Satellite>(num);
            byte[] pattern = decodePattern("Wa]k1cLZb`g`^na4A@<e:UU8`SKj<`C?H3gaI>_[e:eao>_@fE;dT>b]^QT`Nn]OcC3Gd`:WdlgB8JVZjM\\Xnc<a3bZV8E1]ZW@[".toCharArray());
            int[] failure = failure(pattern);
            for (int i = 0; i < num; i++) {
                Satellite satellite = new Satellite();
                satellite.x = Double.valueOf(readLine(r));
                satellite.y = Double.valueOf(readLine(r));
                int offset = search(r, pattern, failure, 10000000);
                readLine(r);
                if (offset >= 0) {
                    satellite.r = offset * 29.9792458;
                    satellites.add(satellite);
                }
                if (satellites.size() >= 6 || satellites.size() >= 2 && System.currentTimeMillis() > timeLimit) break;
            }
        } finally {
            r.close();
        }

        return satellites;
    }

    private static String readLine(InputStream r) throws IOException {
        StringBuilder sb = new StringBuilder();
        int b;
        while ((b = r.read()) >= 0) {
            if (b == '\n') break;
            if (b != '\r') sb.append((char) b);
        }
        return sb.toString().trim();

    }

    private static Point[] triangulate(Satellite s1, Satellite s2) {
        Point pos1, pos2;
        final double margin = 100;

        double d = Math.sqrt((s1.x - s2.x) * (s1.x - s2.x) + (s1.y - s2.y) * (s1.y - s2.y));
        if (Math.abs(d - Math.abs(s1.r - s2.r)) < margin / 2) {
            double sgn = Math.signum(s1.r - s2.r);
            double delta = (d - Math.abs(s1.r - s2.r)) / 2;
            pos1 = new Point(s1.x + (s1.r - delta) * (s2.x - s1.x) / d * sgn,
                    s1.y + (s1.r - delta) * (s2.y - s1.y) / d * sgn);
            return new Point[]{pos1};
        } else if (Math.abs(d - (s1.r + s2.r)) < margin / 2) {
            double delta = (d - Math.abs(s1.r + s2.r)) / 2;
            pos1 = new Point(s1.x + (s1.r + delta) * (s2.x - s1.x) / d,
                    s1.y + (s1.r + delta) * (s2.y - s1.y) / d);
            return new Point[]{pos1};
        } else if (d < s1.r + s2.r && d > Math.abs(s1.r - s2.r)) {
            double b = (s2.r * s2.r - s1.r * s1.r + d * d) / (2 * d);
            double a = d - b;
            double h = Math.sqrt(s1.r * s1.r - a * a);
            Point p0 = new Point(s1.x + a / d * (s2.x - s1.x),
                    s1.y + a / d * (s2.y - s1.y));
            pos1 = new Point(p0.x + h / d * (s2.y - s1.y),
                    p0.y - h / d * (s2.x - s1.x));
            pos2 = new Point(p0.x - h / d * (s2.y - s1.y),
                    p0.y + h / d * (s2.x - s1.x));

            double p1d = pos1.x * pos1.x + pos1.y * pos1.y;
            double p2d = pos2.x * pos2.x + pos2.y * pos2.y;
            final double earth = 6378000.0 * 6378000.0;
            if (p1d > earth) {
                if (p2d > earth) return new Point[0];
                else return new Point[]{pos2};
            } else {
                if (p2d > earth) return new Point[]{pos1};
                else return new Point[]{pos1, pos2};
            }
        }
        return new Point[0];
    }

    private static byte[] decodePattern(char[] encoded) {
        byte[] b = new byte[60 * encoded.length];
        for (int i = 0; i < encoded.length; i++) {
            int c = encoded[i] - '0';
            for (int j = 0; j < 6; j++) {
                int d = (c >> j) & 1;
                Arrays.fill(b, (i * 6 + j) * 10, (i * 6 + j + 1) * 10, (byte) ('0' + d));
            }
        }
        return b;
    }


    private static class Point {
        double x;
        double y;

        public Point() {
        }

        public Point(double x, double y) {
            this.x = x;
            this.y = y;
        }
    }

    private static class Satellite extends Point {
        double r;
    }

    public static int search(InputStream data, byte[] pattern, int[] failure, int length) throws IOException {
        int sum = length + pattern.length;
        int j = 0;
        int read = 0;
        ByteBuffer buffer = ByteBuffer.allocate(length);
        for (int i = 0; i < sum; i++) {
            byte d;
            if (i < length) {
                d = (byte) data.read();
                buffer.put(d);
                read++;
            } else {
                d = buffer.get(i - length);
            }
            while (j > 0 && pattern[j] != d) {
                j = failure[j - 1];
            }
            if (pattern[j] == d) {
                j++;
            }
            if (j == pattern.length) {
                skip(data, length - read);
                return i - pattern.length + 1;
            }
        }
        return -1;
    }

    public static void skip(InputStream data, int skip) throws IOException {
        try {
            while (skip > 0) {
                skip -= data.skip(skip);
            }
        } catch (IOException e) {
            if (e.getMessage().contains("Illegal seek")) { // pipe skip is much slower: cat test | java Glonass
                while (skip > 0) {
                    int b = data.read();
                    if (b < 0) break;
                    skip--;
                }
            } else throw e;
        }
    }

    private static int[] failure(byte[] pattern) {
        int[] failure = new int[pattern.length];
        int j = 0;
        for (int i = 1; i < pattern.length; i++) {
            while (j > 0 && pattern[j] != pattern[i]) {
                j = failure[j - 1];
            }
            if (pattern[j] == pattern[i]) {
                j++;
            }
            failure[i] = j;
        }
        return failure;
    }

}
