//@shuternay

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;

public class Main {
    private static final double C = 299792458;

    public static void main(String[] args) throws IOException {
        BufferedReader br = new BufferedReader(new InputStreamReader(System.in));

        int n = Integer.parseInt(br.readLine());
        Point[] satellites = new Point[Math.min(n, 25)];
        double[] r = new double[Math.min(n, 25)];

        final int blSize = 100000;
        char bf[] = new char[blSize];
        byte[] sb = new byte[(int) 1e6];

        double minCos = 2;
        Point C1 = new Point(), C2 = new Point(),
                CurC1 = new Point(), CurC2 = new Point();

        for (int i = 0; i < Math.min(n, 25); ++i) {
//            long s1 = System.nanoTime();
//            long e1 = System.nanoTime();
//            System.out.println("i:" + String.valueOf(i) +
//                    " t: " + String.valueOf((e1 - s1)/1e6));

            satellites[i] = new Point();
            satellites[i].x = Double.parseDouble(br.readLine());
            satellites[i].y = Double.parseDouble(br.readLine());

            br.read(bf, 0, blSize);
            int mShift = 0;
            for (int j = 0; j < bf.length; ++j)
                if (bf[0] != bf[j]) {
                    mShift = j % 10;
                    if (mShift == 0)
                        mShift = 10;
                    break;
                }

            for (int j = 0; j < blSize / 10; ++j)
                sb[j] = (byte) (bf[10 * j] - '0');

            for (int j = 1; j < (int) 1e7 / blSize; ++j) {
                br.read(bf, 0, blSize);

                for (int k = 0; k < blSize; k += 10)
                    sb[(j * blSize + k) / 10] = (byte) (bf[k] - '0');
            }

            br.readLine();

            int shift = Finder.getShift(sb);

            double time = shift * 10 + mShift - 10;
            time /= 1e7 / C;
            r[i] = time;

            for (int j = 0; j < i; ++j) {
                double curCos = Point.getIntersection(satellites[i], r[i], satellites[j], r[j], CurC1, CurC2);
                if (curCos < minCos) {
                    C1.set(CurC1);
                    C2.set(CurC2);
                    minCos = curCos;
                }
            }
        }

        if (minCos > 1.9) {
            C1.set(satellites[0]);
            C2.set(satellites[1]);
        }

        double v1 = Point.normForS(C1, satellites, r);
        double v2 = Point.normForS(C2, satellites, r);

        Boolean isC1ok = Point.checkPos(C1, satellites, r),
                isC2ok = Point.checkPos(C2, satellites, r);

        if (isC1ok && !isC2ok) {
            System.out.print(C1.x);
            System.out.print(" ");
            System.out.println(C1.y);
            return;
        }
        if (!isC1ok && isC2ok) {
            System.out.print(C2.x);
            System.out.print(" ");
            System.out.println(C2.y);
            return;
        }

        if (v1 < v2) {
            System.out.print(C1.x);
            System.out.print(" ");
            System.out.println(C1.y);
        } else {
            System.out.print(C2.x);
            System.out.print(" ");
            System.out.println(C2.y);
        }
    }
}

class Finder {
    public static int getShift(byte[] s) {
        int n = s.length;

        int zCnt = 0;
        for (int i = 0; i < n; ++i) {
            if (s[i] == 0)
                zCnt++;
            else
                zCnt = 0;
            if (zCnt == 18)
                return (i - 42757 + n) % n;
        }
        for (int i = 0; i < 30; ++i) {
            if (s[i] == 0)
                zCnt++;
            else
                zCnt = 0;
            if (zCnt == 18)
                return (i - 42757 + n) % n;
        }

        return -1;
    }
}

class Point {
    public double x, y;

    public Point() {
        x = y = 0;
    }

    public Point(double _x, double _y) {
        x = _x;
        y = _y;
    }

    public static double getIntersection(
            Point A,
            double ra,
            Point B,
            double rb,
            Point O1,
            Point O2) {

        if (ra > rb + 100)
            return getIntersection(B, rb, A, ra, O1, O2);

        // ra <= rb

        double d = A.distTo(B);

        double cosa = (ra * ra + d * d - rb * rb) / (2 * ra * d);
        double a = 0;
        if (cosa < 1)
            a = Math.acos(cosa);
        Point v = B.minus(A).norm(ra);
        O1.set(A.plus(v.rotate(a)));
        O2.set(A.plus(v.rotate(-a)));

        return Math.abs(cosa);
    }

    public static Boolean checkPos(
            Point X,
            Point[] O,
            double[] r) {

        if (X.len() > 6378000 + 0.1)
            return false;

        for (int i = 0; i < O.length; ++i)
            if (Math.abs(X.distTo(O[i]) - r[i]) > 500)
                return false;

        return true;
    }

    public static double normForS(
            Point X,
            Point[] O,
            double[] r) {

        double gMinV = 1e18;

        for (double st = 50.0; st > 1; st /= 1.5) {
            double minV = 1e18, minX = 0, minY = 0;

            for (int i = -2; i <= 2; ++i)
                for (int j = -2; j <= 2; ++j) {
                    double S = 0;
                    Point CX = new Point(X.x + i * st, X.y + j * st);

                    for (int l = 0; l < O.length; ++l) {
                        double d = CX.distTo(O[l]) - r[l];
                        S += d * d;
                    }

                    if (S < minV) {
                        minV = S;
                        minX = CX.x;
                        minY = CX.y;
                    }
                }
            gMinV = minV;
            X.x = minX;
            X.y = minY;
        }

        return gMinV;
    }

    public void set(Point p) {
        x = p.x;
        y = p.y;
    }

    public Point plus(Point p) {
        return new Point(x + p.x, y + p.y);
    }

    public Point minus(Point p) {
        return new Point(x - p.x, y - p.y);
    }

    public Point mult(double k) {
        return new Point(x * k, y * k);
    }

    public Point norm(double k) {
        return this.mult(k / this.len());
    }

    public Point rotate() {
        //noinspection SuspiciousNameCombination
        return new Point(-y, x);
    }

    public Point rotate(double a) {
        Point u = this;
        Point v = u.rotate();

        // u * cos(a) + v * sin(a)
        return u.mult(Math.cos(a)).plus(v.mult(Math.sin(a)));
    }

    public double distTo(Point p) {
        //return this.minus(p).len();
        return Math.sqrt((x - p.x) * (x - p.x) + (y - p.y) * (y - p.y));
    }

    public double len() {
        return Math.sqrt(x * x + y * y);
    }
}