//@vadimmm
import java.io.*;

import static java.lang.Double.*;
import static java.lang.Integer.*;
import static java.lang.Math.*;

public class Solution {
    private static final double EPS = 1e-8;
    private static final int LEN = 190;
    private static final int POS = 6_375_480;
    private static final double C = 29.9792458;

    private void run() throws IOException {
        BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
        int counter = parseInt(in.readLine());
        Circle[] circles = new Circle[counter];
        for (int i = 0; i < counter; i++) {
            circles[i] = new Circle(
                    new Point(parseDouble(in.readLine()), parseDouble(in.readLine())),
                    calculateRadius(in.readLine())
            );
        }
        if (counter == 2) {
            System.out.println(circles[0].intersect(circles[1])[0]);
        } else {
            Point[] points = circles[0].intersect(circles[1]);
            Point[] other = circles[0].intersect(circles[2]);
            int idx = -1;
            double minDistance = 1e9;
            for (int i = 0; i < points.length; i++) for (int j = 0; j < other.length; j++) {
                double distance = points[i].distanceTo(other[j]);
                if (distance < minDistance) {
                    minDistance = distance;
                    idx = i;
                }
            }
            System.out.println(points[idx]);
        }
    }

    private double calculateRadius(String s) {
        int i;
        for (i = 0; i < s.length(); i++) if (s.charAt(i) == '1'){
            int cur = 0;
            while (i + cur < s.length() && s.charAt(i + cur) == '1') cur++;
            if (cur == LEN) break;
            i += cur - 1;
        }
        int offset = i - POS;
        System.err.println("offset: " + offset);
        double result = C * offset;
        System.err.println(result);
        return result;
    }

    static class Circle {
        public Point center;
        public double radius;

        Circle(Point center, double radius) {
            this.center = center;
            this.radius = radius;
        }

        public Point[] intersect(Circle other) {
            double distance = this.center.distanceTo(other.center);
            if ((distance > this.radius + other.radius + EPS) ||
                    (distance + min(this.radius, other.radius) + EPS < max(this.radius, other.radius))) {
                return new Point[0];
            }
            if (abs(this.center.x - other.center.x) < EPS && abs(this.center.y - other.center.y) < EPS) {
                return new Point[3];
            }
            double d = ((this.radius * this.radius - other.radius * other.radius) / distance + distance) * .5;
            Point temp = other.center.subtract(this.center);
            Point base = temp.multiply(d / temp.length());
            base = this.center.add(base);
            double dd = (this.radius * this.radius - d * d);
            if (dd < EPS) {
                return new Point[]{base};
            }
            dd = sqrt(dd);
            Point shift = new Point(-temp.y, temp.x).multiply(dd / temp.length());
            return new Point[]{base.add(shift), base.subtract(shift)};
        }
    }

    static class Point {
        public double x, y;

        Point(double x, double y) {
            this.x = x;
            this.y = y;
        }

        public Point add(Point other) {
            return new Point(x + other.x, y + other.y);
        }

        public Point subtract(Point other) {
            return new Point(x - other.x, y - other.y);
        }

        public Point multiply(double mul) {
            return new Point(x * mul, y * mul);
        }

        public double length() {
            return sqrt(x * x + y * y);
        }

        public double distanceTo(Point other) {
            return sqrt(sqartedDistanceTo(other));
        }

        public double sqartedDistanceTo(Point other) {
            double dx = x - other.x;
            double dy = y - other.y;
            return dx * dx + dy * dy;
        }

        @Override
        public String toString() {
            return x + " " + y;
        }
    }

    public static void main(String[] args) throws IOException {
        new Solution().run();
    }
}
