//@xio4
import java.lang.Math;
import java.io.InputStream;
import java.util.ArrayList;
import java.io.IOException;
import java.io.*;
import java.util.Comparator;
import java.util.Collections;
public class Solver0
{

	private static final double SL					= 299792458.0;
	private static final double R_MAX_POS			= 6378000.0;
	private static final double R_MAX_POS_2		= 40678884000000.0;
	private static final double S_MIN_POS			= 10000000.0;
	private static final double S_MAX_POS			= 20000000.0;

//	private static final int BB_SIZE = 32768;
//	private static final int BB_SIZE					= 65536;
	private static final int BB_SIZE					= 131072;
//	private static final int BB_SIZE = 262144;
//	private static final int BB_SIZE = 524288;

	private static final int D_PTRN					= 15;
	private static final int UNIQ_OFFSET			= 524870;
	private static final int START_OFFSET			= 120800+UNIQ_OFFSET;
	private static final int END_OFFSET				= 879900+UNIQ_OFFSET;

	private static final int PTRN_DATA_LEN			= (END_OFFSET/BB_SIZE+1)*BB_SIZE;
	private static final int DATA_LEN				= 10000000; 
	private static final int S_MAX_COUNT			= 255;
	private static final int CPUS						= 2;
	private static final double EPS					= (double)1E-6;
	// Correct ERROR!!
	private static final double ERR					= (double)(SL/(double)10000000.0/(double)2.0);
	private static final double PI_DEG				= (double)180.0/Math.PI;
	private static final int SEC_COUNT				= 360/15;
	private static final double MIN_ANGLE			= Math.PI/(double)2.0;
	private static final double NEAR_ERR_2			= 60*60;
	private static final int C_SIZE_MAX				= 20;
	
	private ArrayList<Satellite> satellites;
	private Vec2 rCoord;

	
	class Vec2 {
		public double x;
		public double y;
	}



	class Satellite {
		public Satellite()
		{
			coord = new Vec2();
		}
		public Vec2 coord;
		public int offset;
		public double len;
	}
	public Solver0()
	{
		satellites = new ArrayList<Satellite>();
		rCoord = new Vec2();
	}

	class OffsetFinder implements Runnable
	{
		private byte[] data;
		private Satellite stl;

		public OffsetFinder(byte[] data, Satellite stl)
		{
			this.data = data;
			this.stl = stl;
		}

		@Override
		public void run()
		{
			byte ch = data[0];
			int correction = 0;
			for (int i= 1; i < 190; ++i) {
				if (ch != data[i]) {
					if (i % 10 != 0) {
						correction = i % 10 - 10;
					}
					break;
				}
			}
			ch = data[START_OFFSET];
			int l = 1;
			for (int i=START_OFFSET+10; i < END_OFFSET; i += 10)
			{
				if (ch == data[i]) {
					l++;
				}
				else {
					if (l == D_PTRN) {
						stl.offset = i - l*10 - UNIQ_OFFSET + correction;
						stl.len = SL*(double)stl.offset/(double)10000000.0;
	//					System.out.println(String.format("len %.3f",stl.len));
						break;
					}

					l = 1;
					ch = data[i];
				}
			}
		}
	}

	class SatelliteStore
	{
		private int pos;
		private ArrayList<Satellite> stls;
		public SatelliteStore()
		{
			pos = 0;
			stls = new ArrayList<Satellite>();
		}
		public void add(Satellite stl)
		{
			stls.add(stl);
		}
		public boolean hasNext()
		{
			if (pos < stls.size())
				return true;
			return false;
		}
		public Satellite next()
		{
			if (pos < stls.size()) {
				return stls.get(pos++);
			}
			return null;
		}

	}
	public Vec2[] computeIntersection2(Satellite stl1, Satellite stl2)
	{

		Vec2[] res = null;
		double dX = stl2.coord.x - stl1.coord.x;
		double dY = stl2.coord.y - stl1.coord.y;
		double dist = Math.sqrt(dX*dX + dY*dY);
		double R1 = stl1.len;
		double R2 = stl2.len;
		double sign = 0.0;
		double delta = 0.0;

//		System.out.println("Stl1.len="+stl1.len);
//		System.out.println("Stl2.len="+stl2.len);

		if (Math.abs(dist - Math.abs(R1 - R2)) < ERR) {
			res = new Vec2[1];
			res[0] = new Vec2();
			sign = ((R1-R2) < EPS) ? 0.0 : ((R1-R2)>0) ? 1.0 : -1.0;
			delta = (dist - Math.abs(R1 - R2)) / (double)2.0;
			res[0].x = stl1.coord.x + (R1 - delta)*dX / dist * sign;
			res[0].y = stl1.coord.y + (R1 - delta)*dY / dist * sign;
		}
		else if (Math.abs(dist - (R1 + R2)) < ERR) {
			res = new Vec2[1];
			res[0] = new Vec2();
			delta = (dist - Math.abs(R1 + R2)) / (double)2.0;
			res[0].x = stl1.coord.x + (R1 + delta)*dX / dist;
			res[0].y = stl1.coord.y + (R1 + delta)*dY / dist;

		}
		else if ((dist < (R1 + R2)) && (dist > Math.abs(R1 - R2))) {
			res = new Vec2[2];
			res[0] = new Vec2();
			res[1] = new Vec2();
			double b = (R2 * R2 - R1 * R1 + dist*dist) / ((double)2.0*dist);
			double a = dist - b;
			double h = Math.sqrt(R1*R1 - a*a);
			double px = stl1.coord.x + a/dist*dX;
			double py = stl1.coord.y + a/dist*dY;
			double hDist = h/dist;
			res[0].x = px + hDist*dY;
			res[0].y = py - hDist*dX;
			res[1].x = px - hDist*dY;
			res[1].y = py + hDist*dX;
		}
		return res;

	}


	public void loadAndFindOffset()
	{
		byte[][] data = new byte[CPUS][];	
		InputStream stdin = System.in;
		Thread[] threadArr = new Thread[CPUS];

		//Get satellites count
		int stlCount = 0;
		int startPos = 0;
		int curPos = 0;
		int nRead = 0;
		int readSize = BB_SIZE;
		int crLen = 1;
		int threadCounter = 0;
		byte[] tmpData = new byte[BB_SIZE*2];
		try {
			while ((nRead = stdin.read(tmpData, curPos, 1)) != -1) {
				if (nRead > 0) {
					if (tmpData[curPos] == 0x0A) {
						if ((tmpData[curPos-1] == 0x0D)) {
							crLen = 2;
						}
						stlCount = Integer.parseInt(new String(tmpData, startPos, curPos-crLen+1-startPos));
//						System.out.println("stlCount="+stlCount);
						break;
					}
					curPos += nRead;
				}
			}

			if (stlCount > S_MAX_COUNT) {
				stlCount = S_MAX_COUNT;
			}

			for (int stlPos = 0; stlPos < stlCount; ++stlPos) {
				
				Satellite stl = new Satellite();
				satellites.add(stl);
				curPos = 0;
				startPos = 0;
				while ((nRead = stdin.read(tmpData, curPos, BB_SIZE)) != -1) {
					curPos += nRead;	
					if (curPos >= BB_SIZE) {
						// Get X coord
						for (int i = startPos; i < curPos; ++i) {
							if (tmpData[i] == 0x0A) {
								stl.coord.x = Double.parseDouble(new String(tmpData, startPos, 
										i-crLen+1-startPos));

//								System.out.println("stl.coord.x="+stl.coord.x);
								startPos = i+1;
								break;
							}
						}
						// Get Y coord
						for (int i = startPos; i < curPos; ++i) {
							if (tmpData[i] == 0x0A) {
								stl.coord.y = Double.parseDouble(new String(tmpData, startPos, 
									i-crLen+1-startPos));

//								System.out.println("stl.coord.y="+stl.coord.y);
								startPos = i+1;
								break;

							}
						}
						if (threadArr[threadCounter] != null) {
							threadArr[threadCounter].join();
						}
						if (data[threadCounter] == null) 
							data[threadCounter] = new byte[PTRN_DATA_LEN];
						System.arraycopy(tmpData, startPos, data[threadCounter], 0, curPos-startPos);
						curPos = curPos-startPos;
						break;
					}
				}
				readSize = BB_SIZE;
				while ((nRead = stdin.read(data[threadCounter], curPos, readSize)) != -1) {
					curPos += nRead;
					readSize = Math.min(BB_SIZE, PTRN_DATA_LEN-curPos);
					if (readSize == 0) {
						OffsetFinder oFinder = new OffsetFinder(data[threadCounter], stl);
						if (threadArr[threadCounter] != null) {
							threadArr[threadCounter].join();
						}
						Thread thrFinder = new Thread(oFinder);
						threadArr[threadCounter] = thrFinder;
						thrFinder.start();
						threadCounter++;
						if (threadCounter >= threadArr.length) {
							threadCounter = 0;
						}
						long skipCounter = 0;
						long skipVal = DATA_LEN-PTRN_DATA_LEN;
						while (skipCounter < DATA_LEN - PTRN_DATA_LEN + 2) { 
							skipCounter += stdin.skip(skipVal);
							skipVal = DATA_LEN - PTRN_DATA_LEN + 2 - skipCounter; 
							
						}
//						System.out.println("DATA_LEN - PTRN_DATA_LEN+2="+(DATA_LEN-PTRN_DATA_LEN+2));
//						System.out.println("skipCounter="+skipCounter);
						break;
					}
				}
			}
			for (int i=0; i < CPUS; ++i) {
				if (threadArr[i] != null)
					threadArr[i].join();
			}
		}
		catch (InterruptedException e) {
			e.printStackTrace();
		}
		catch (IOException e) {
			e.printStackTrace();
		}
	}

	private double getAngle2(Satellite stl1, Satellite stl2, Vec2 baseV)
	{
		double dX1 = stl1.coord.x - rCoord.x;
		double dY1 = stl1.coord.y - rCoord.y;
		double dX2 = stl2.coord.x - rCoord.x;
		double dY2 = stl2.coord.y - rCoord.y;
		double val = (dX1*dY1+dX2*dY2)/(stl1.len*stl2.len);
		if (Math.abs(val - (double)1.0) < EPS) {
			val = (double)1.0-EPS;
		}
		if (Math.abs(val) < EPS) {
			val = EPS;
		}
		double res = Math.acos((dX1*dY1+dX2*dY2)/(stl1.len*stl2.len));

		if (Double.isNaN(res)) {
			return 0.0;
		}
		return res;
	}

	public int checkRange(Vec2[] v)
	{
		int res = -1;
		if (v == null) 
			return res;
		if (v.length == 1) {
			if ((v[0].x*v[0].x + v[0].y*v[0].y) <= R_MAX_POS_2) 
				res++;
		}
		else {
			if ((v[0].x*v[0].x + v[0].y*v[0].y) <= R_MAX_POS_2) 
				res++;
			if ((v[1].x*v[1].x + v[1].y*v[1].y) <= R_MAX_POS_2) { 
				if (res == 0)	
					res+=2;
				else res = 1;
			}
		}
		return res;
	}


	private Vec2 getNearVec(Vec2[] vv, Vec2 vChecker)
	{
		if ((vv != null) && (vChecker != null)) {
			double dX = vChecker.x - vv[0].x;
			double dY = vChecker.y - vv[0].y;
			double r1 = dX*dX + dY*dY ;
			if (vv.length > 1) {
				dX = vChecker.x - vv[1].x;
				dY = vChecker.y - vv[1].y;
				double r2 = dX*dX + dY*dY;
				if (r2 > r1)
					return vv[0];
				else 
					return vv[1];
			}
			else {
				return vv[0];
			}
		}
		return null;
	}
	private Vec2 getPrecNearVec(Vec2[] vv, Vec2 vChecker)
	{
		if ((vv != null) && (vChecker != null)) {
			double dX = vChecker.x - vv[0].x;
			double dY = vChecker.y - vv[0].y;
			double r1 = dX*dX + dY*dY ;
			if (vv.length > 1) {
				dX = vChecker.x - vv[1].x;
				dY = vChecker.y - vv[1].y;
				double r2 = dX*dX + dY*dY;
				if (r2 > r1) {
					if (r1 > NEAR_ERR_2)
						return null;
					return vv[0];
				}
				else {
					if (r2 > NEAR_ERR_2)
						return null;
					return vv[1];
				}
			}
			else {
				if (r1 > NEAR_ERR_2) 
					return null;
				return vv[0];
			}
		}
		return null;
	}

	private Vec2 get21avg(Vec2[] vv, Vec2 v)
	{
		Vec2 tmp =  getNearVec(vv, v);
		if (tmp == null) {
			return v;
		}
		Vec2 root = new Vec2();
		root.x = (tmp.x + v.x)/(double)2.0;
		root.y = (tmp.y + v.y)/(double)2.0;

		return root;
	}
	private Vec2 get22avg(Vec2[] vv1, Vec2[] vv2)
	{
		double dX;
		double dY;
		Vec2 root = new Vec2();
		if ((vv1 == null) || (vv2 == null)) {
			return null;
		}

		dX = vv1[0].x - vv2[0].x;
		dY = vv1[0].y - vv2[0].y;
		double r1 = dX*dX + dY*dY;
		dX = vv1[0].x - vv2[1].x;
		dY = vv1[0].y - vv2[1].y;
		double r2 = dX*dX + dY*dY;
		dX = vv1[1].x - vv2[0].x;
		dY = vv1[1].y - vv2[0].y;
		double r3 = dX*dX + dY*dY;
		dX = vv1[1].x - vv2[1].x;
		dY = vv1[1].y - vv2[1].y;
		double r4 = dX*dX + dY*dY;
		if (r1 > r2) {
			if (r2 > r3) {
				if (r3 > r4) {
					// r4 min
					root.x = (vv1[1].x + vv2[1].x)/(double)2.0;
					root.y = (vv1[1].y + vv2[1].y)/(double)2.0;
				}
				else {
					// r3 min
					root.x = (vv1[1].x + vv2[0].x)/(double)2.0;
					root.y = (vv1[1].y + vv2[0].y)/(double)2.0;
				}
			}
			else {
				if (r2 > r4) {
					// r4 min
					root.x = (vv1[1].x + vv2[1].x)/(double)2.0;
					root.y = (vv1[1].y + vv2[1].y)/(double)2.0;
				}
				else {
					// r2 min
					root.x = (vv1[0].x + vv2[1].x)/(double)2.0;
					root.y = (vv1[0].y + vv2[1].y)/(double)2.0;
				}
			}
		}
		else {
			if (r1 > r3) {
				if (r3 > r4) {
					// r4 min
					root.x = (vv1[1].x + vv2[1].x)/(double)2.0;
					root.y = (vv1[1].y + vv2[1].y)/(double)2.0;
				}
				else {
					// r3 min
					root.x = (vv1[1].x + vv2[0].x)/(double)2.0;
					root.y = (vv1[1].y + vv2[0].y)/(double)2.0;
				}
			}
			else {
				if (r1 > r4) {
					// r4 min
					root.x = (vv1[1].x + vv2[1].x)/(double)2.0;
					root.y = (vv1[1].y + vv2[1].y)/(double)2.0;
				}
				else {
					// r1 min
					root.x = (vv1[0].x + vv2[0].x)/(double)2.0;
					root.y = (vv1[0].y + vv2[0].y)/(double)2.0;
				}
			}
		}
		return root;

	}

	private Vec2 getCheckedCoord(Vec2[] vv1, Vec2[] vv2)
	{
		Vec2 root = new Vec2();
		int p1 = checkRange(vv1);
		int p2 = checkRange(vv2);

		if (p1 < 0) {
			return null;
		}

		if (p2 < 0) {
			return null;
		}

		if (p1 < 2 ) {
			if (p2 == 2) {
				root = get21avg(vv2, vv1[p1]);

			} else {
				root.x = (vv1[p1].x + vv2[p2].x)/(double)2.0;
				root.y = (vv1[p1].y + vv2[p2].y)/(double)2.0;
			}
		}
		else {
			if (p2 == 2) {
				root = get22avg(vv1, vv2);
			}
			else {
				root = get21avg(vv1, vv2[p2]);
			}

		}
		return root;

	}
	private Vec2 simpleCompute3(Satellite stl1, Satellite stl2, Satellite stl3)
	{
//		Vec2 root = new Vec2();
		Vec2[] roots1 = computeIntersection2(stl1, stl2);
		Vec2[] roots2 = computeIntersection2(stl2, stl3);
		return getCheckedCoord(roots1, roots2);

	}
	class AngleStore
	{
		public Satellite stl1;
		public Satellite stl2;
		public double angle;
		
	}

	class AngleComparator implements Comparator<AngleStore> 
	{
		@Override
		public int compare(AngleStore ss1, AngleStore ss2) 
		{
//			if (ss1.angle > ss2.angle)
//				return -1;
//			else if (ss1.angle < ss2.angle)
//				return 1;
//			return 0;
			if (ss1.angle > ss2.angle)
				return -1;
			else 
				return 1;

		}

	}

	private Vec2 precissionCompute(int size, Vec2 baseCoord)
	{
		Vec2 root = new Vec2();
		Vec2 newBase = baseCoord;
		ArrayList<AngleStore> asArr = new ArrayList<AngleStore>();
		ArrayList<Vec2> roots = new ArrayList<Vec2>();
		size = Math.min(size, satellites.size());
		for (int i=0; i < size; ++i) {
			Satellite stli = satellites.get(i);
			for (int j=i+1; j < size; ++j) {
				Satellite stlj = satellites.get(j);
				AngleStore as = new AngleStore();	
				as.stl1 = stli;

				as.stl2 = stlj;
				as.angle = getAngle2(stli, stlj, baseCoord);
//				System.out.println("as.angle=" + as.angle);
				asArr.add(as);
			}
		}

		Collections.sort(asArr, new AngleComparator());


		double curAngle = Math.PI;
		int it = 0;
		int it0 = 0;
		while (it0 < asArr.size()-1) {
			Vec2[] vv1 = computeIntersection2(asArr.get(it0).stl1, asArr.get(it0).stl2);
			Vec2[] vv2 = computeIntersection2(asArr.get(it0+1).stl1, asArr.get(it0+1).stl2);
			newBase = getCheckedCoord(vv1, vv2);
			if (newBase != null)
				break;
			it0++;
		}
		for (int i = it0; i < asArr.size(); ++i) {
			AngleStore as = asArr.get(i);
			
			Vec2[] vv = computeIntersection2(as.stl1, as.stl2);
			int r = checkRange(vv);
			if (r < 0) {

//				System.out.println("Cont");
				continue;
			}
			if (r == 2) {
				roots.add(getPrecNearVec(vv, newBase));
//				if (getPrecNearVec(vv, newBase) == null) {
//					System.out.println("V");
//				}
//				System.out.println("NearVec "+getPrecNearVec(vv, newBase).x + ", " + getPrecNearVec(vv, newBase).y);
			}
			else {
//				System.out.println("NearVec "+vv[r].x + ", " + vv[r].y);
				roots.add(vv[r]);
			}

			it++;
			if ((curAngle < MIN_ANGLE) && (it > 1) && (it > C_SIZE_MAX)) {
				break;
			}
		}

		double sx = (double)0.0;
		double sy = (double)0.0;
		int cnt = 0;
		for (Vec2 v: roots) {
			if (v != null) {
				cnt++;
				sx += v.x;
				sy += v.y;
			}
		}

		root.x = sx / (double)cnt;
		root.y = sy / (double)cnt;
		return root;	
	}

	public void solve()
	{
		loadAndFindOffset();

		if (satellites.size() == 2) {
			Vec2[] v = computeIntersection2(satellites.get(0), satellites.get(1));
			if (v == null) {
					System.out.println("0.000 0.000");
			}
			int pos = checkRange(v);
			if ((pos >= 0)) {
				if (pos < 2)
					System.out.println(String.format("%.3f", v[pos].x)+" "+String.format("%.3f",v[pos].y));
				else
					System.out.println(String.format("%.3f", v[0].x)+" "+String.format("%.3f",v[0].y));
				return;
			}
	
		}
		else {

			Vec2 v2 = simpleCompute3(satellites.get(0), satellites.get(1), satellites.get(2));
			if (v2 == null) {
				System.out.println("0.000 0.000");
				return;
			}
			rCoord = precissionCompute(C_SIZE_MAX, v2);

		}

		if (rCoord == null) {
			System.out.println("0.000 0.000");
		}
		System.out.println(String.format("%.3f", rCoord.x)+" "+String.format("%.3f",rCoord.y));

	}

	public static void main(String[] args)
	{
		final long startTime = System.currentTimeMillis();
		Solver0 solver = new Solver0();
		solver.solve();
		final long endTime = System.currentTimeMillis();
//		System.out.println("Total exec time: " + (endTime - startTime));


	}
}
