//@zzerga
import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.InputStreamReader;

import static java.lang.System.out;

public class Glonass {

    public static final double MAX_R = 6.38e6;
    public static final double MAX_DOM = 1e4;
    public static final double C = 299792458.0;
    public static final double T_FREQ = 1e-7;

    public static final long T_HALT_PRE = 4000;
    public static final long T_HALT = 4700;

    public static final int N_BASTA = 7;
    public static final int N_ESTIMS = 7 * 3;

    static final double D_MIN = 1e6;
    static final double D_OPT = 1e7;

    public static final String LAST_20 = "00000000001111111111000000000000000000000000000000111111111111111111110000000000111111111111111111111111111111000000000000000000000000000000111111111100000000000000000000000000000011111111110000000000";

    private static Sat[] sats = new Sat[N_BASTA];
    static int n = 0;
    private static Sat[] estims = new Sat[N_ESTIMS];
    static int nEst = 0;
    static double domX = -1e8;
    static double domY = -1e8;
    static double x = 0.0;
    static double y = 0.0;

    static final int SAMPLE = 10000000;
    static int winShift = 120000;
    static final int N_BUF = 430000;
    static char[] buf = new char[N_BUF];

    private static long initTimeMs;
    private static long prevTimeMs;
    private static long timeMs;

    public static void main(String[] args) throws Exception {

        // TODO Simulate in
        // FileInputStream stream = new FileInputStream("example/glonass-contest/test2b.in");
        // System.setIn(stream);

        initTimeMs = prevTimeMs = System.currentTimeMillis();
        BufferedReader br = new BufferedReader(new InputStreamReader(System.in));

        String line;

        /* Header */
        line = br.readLine();
        int nSat = Integer.parseInt(line);

        boolean skip;

        /* read sat */
        double dMin;
        for (int i = 0; i < nSat; i++) {
            x = Double.parseDouble(br.readLine());
            y = Double.parseDouble(br.readLine());

            skip = false;
            if(System.currentTimeMillis() - initTimeMs > T_HALT_PRE) {
                dMin = D_MIN;
            } else {
                dMin = D_OPT - (D_OPT - D_MIN) * i / nSat;
            }

            for (int j = 0; j < n; j++) {
                double d = dist(sats[j], x, y);
                if (d < 100.0) {
                    skip = true;
                    break;
                }

                if ( (N_BASTA - n) >= (nSat - i) ) {
                    continue;
                }

                if (d < dMin) {
                    skip = true;
                    break;
                }
            }

            if (skip) {
                /* Skip sat */
                br.skip(SAMPLE);
                br.readLine();
            } else {
                // TODO find shift efficiently
                double rSat = distCenter(x, y);
                int winShift = (int) ((rSat - MAX_R) * SAMPLE / C ) - 300;
                br.skip(winShift);
                br.read(buf, 0, N_BUF);
                line = new String(buf);
                br.skip(SAMPLE - winShift - N_BUF);
                br.readLine();
                int shift = winShift + line.indexOf(LAST_20) + LAST_20.length();

                double l = (shift * T_FREQ * C); // TODO does it help?  - 15.0
                Sat sat = new Sat(x, y, l, rSat);
                sats[n] = sat;

                /* Position estimations */
                for (int j = 0; j < n; j++) {
                    Sat est = new Sat(sat, sats[j]);
                    estims[nEst++] = est;
                }

                n++;
            }

            if (n == N_BASTA || System.currentTimeMillis() - initTimeMs > T_HALT)  {
                break;
            }
        } // for sat in file

        finalAverage();
        out.printf("%.0f %.0f\n", x, y);

//        timeMs = System.currentTimeMillis();
//        out.printf("TOTAL: %d \n", (timeMs - initTimeMs));
    }

    static class Sat {
        double x;
        double y;
        double l;
        double r;
        double xa;
        double ya;

        Sat(double xx, double yy, double z, double rr) {
            x = xx;
            y = yy;
            r = rr;
            l = z;
            xa = -1e8;
            ya = -1e8;
        }

        /* Calculate position estimation */
        Sat(Sat s1, Sat s2) {
            // TODO optimize?
            double d = Math.sqrt((s1.x - s2.x)*(s1.x - s2.x) + (s1.y - s2.y)*(s1.y - s2.y));
            double t1 = (s1.l - s2.l) * (s1.l + s2.l) / d;
            double a = 0.5 * (d + t1);
            double c = Math.sqrt(s1.l*s1.l - a*a);

            double rx = (s2.x - s1.x) / d;
            double ry = (s2.y - s1.y) / d;

            double x1 = s1.x + a*rx - c*ry;
            double y1 = s1.y + a*ry + c*rx;
            double r1 = distCenter(x1, y1);
            boolean ok1 = checkCenterDom(r1, x1, y1, false);

            double x2 = s1.x + a*rx + c*ry;
            double y2 = s1.y + a*ry - c*rx;
            double r2 = distCenter(x2, y2);
            boolean ok2 = checkCenterDom(r2, x2, y2, !ok1);

            rx = s1.x / s1.r;
            ry = s1.y / s1.r;
            a = s2.x / s2.r;
            c = s2.y / s2.r;
            l = dist(rx, ry, a, c);

            xa = -1e8;
            ya = -1e8;
            if (ok1) {
                x = x1;
                y = y1;
                if (ok2) {
                    if (domX < -MAX_R && nEst > 0) {
                        for (int i = 0; i < nEst; i++) {
                            Sat est = estims[i];
                            if (dist(est.x, est.y, x1, y1) > MAX_DOM && dist(est.xa, est.ya, x1, y1) > MAX_DOM) {
                                domX = x = x2;
                                domY = y = y2;
                                break;
                            }
                            if (dist(est.x, est.y, x2, y2) > MAX_DOM && dist(est.xa, est.ya, x2, y2) > MAX_DOM) {
                                domX = x = x1;
                                domY = y = y1;
                                break;
                            }
                        }
                    }
                    if (domX < -MAX_R) {
                        // really cannot choose for now
                        xa = x2;
                        ya = y2;
                    }
                } else {
                    domX = x1;
                    domY = y1;
                }
            } else {
                x = x2;
                y = y2;
                domX = x2;
                domY = y2;
            }

        }

    }


    static double dist(Sat s, double x, double y) {
        return Math.sqrt((s.x - x)*(s.x - x) + (s.y - y)*(s.y - y));
    }

    static double dist(double x, double y, double xx, double yy) {
        return Math.sqrt((xx - x)*(xx - x) + (yy - y)*(yy - y));
    }

    static double distCenter(double x, double y) {
        return Math.sqrt(x*x + y*y);
    }

    static boolean checkCenterDom(double r, double x, double y, boolean insert) {
        if (r > MAX_R) {
            return false;
        }

        if (domX < -MAX_R) {
            if (insert) {
                domX = x;
                domY = y;
            }
            return true;
        }
        return Math.abs(x - domX) < MAX_DOM && Math.abs(y - domY) < MAX_DOM;
    }

    private static void finalAverage() {
        x = y = 0;
        double w = 0.0;

        for (int i=0; i < nEst; i++) {
            Sat e = estims[i];

            /* recheck double issues */
            if (e.xa > -1e7) {
                if (domX > -MAX_R) {
                    if (dist(e, domX, domY) > MAX_DOM) {
                        e.x = e.xa;
                        e.y = e.ya;
                    }
                } else {
                    /* Select main as dominant */
                    domX = e.x;
                    domY = e.y;
                }
            }

            x += e.x * e.l;
            y += e.y * e.l;
            w += e.l;
        }

        x = x / w;
        y = y / w;
    }


}
